% Auto-generated chapter 2 for malik
% Hadiths in this chapter: 114

\hadithdefcmd{malik}{32}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَمْرِو بْنِ يَحْيَى الْمَازِنِيِّ، عَنْ أَبِيهِ، أَنَّهُ قَالَ لِعَبْدِ اللَّهِ بْنِ زَيْدِ بْنِ عَاصِمٍ وَهُوَ جَدُّ عَمْرِو بْنِ يَحْيَى الْمَازِنِيِّ وَكَانَ مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم هَلْ تَسْتَطِيعُ أَنْ تُرِيَنِي كَيْفَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَتَوَضَّأُ فَقَالَ عَبْدُ اللَّهِ بْنُ زَيْدِ بْنِ عَاصِمٍ نَعَمْ ‏.‏ فَدَعَا بِوَضُوءٍ فَأَفْرَغَ عَلَى يَدِهِ فَغَسَلَ يَدَيْهِ مَرَّتَيْنِ مَرَّتَيْنِ ثُمَّ تَمَضْمَضَ وَاسْتَنْثَرَ ثَلاَثًا ثُمَّ غَسَلَ وَجْهَهُ ثَلاَثًا ثُمَّ غَسَلَ يَدَيْهِ مَرَّتَيْنِ مَرَّتَيْنِ إِلَى الْمِرْفَقَيْنِ ثُمَّ مَسَحَ رَأْسَهُ بِيَدَيْهِ فَأَقْبَلَ بِهِمَا وَأَدْبَرَ بَدَأَ بِمُقَدَّمِ رَأْسِهِ ثُمَّ ذَهَبَ بِهِمَا إِلَى قَفَاهُ ثُمَّ رَدَّهُمَا حَتَّى رَجَعَ إِلَى الْمَكَانِ الَّذِي بَدَأَ مِنْهُ ثُمَّ غَسَلَ رِجْلَيْهِ ‏.‏\hadithno{32}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Amr ibn Yahya al-Mazini that his father once asked Abdullah ibn Zayd ibn Asim, who was the grandfather of Amr ibn Yahya al-Mazini and one of the companions of the Messenger of Allah, may Allah bless him and grant him peace, if he could show him how the Messenger of Allah, may Allah bless him and grant him peace, did wudu. Abdullah ibn Zayd ibn Asim agreed to do so and asked for water to do wudu. He poured some out on to his hand and washed each hand twice and then rinsed his mouth and snuffed water up his nose and blew it out three times.Then he washed hisface three times and both of his arms up to the elbows twice. He then wiped his head with both hands, taking his hands from hisforehead to the nape of his neck and then bringing them back to where he had begun. Then he washed his feet}}
\hadithdefcmd{malik}{33}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا تَوَضَّأَ أَحَدُكُمْ فَلْيَجْعَلْ فِي أَنْفِهِ مَاءً ثُمَّ لِيَنْثِرْ وَمَنِ اسْتَجْمَرَ فَلْيُوتِرْ ‏"‏ ‏.‏\hadithno{33}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'zZinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "When you do wudu, snuff water into your nose and blow it out, and if you use stones to clean your private parts use an odd number}}
\hadithdefcmd{malik}{34}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ تَوَضَّأَ فَلْيَسْتَنْثِرْ وَمَنِ اسْتَجْمَرَ فَلْيُوتِرْ ‏"‏ ‏.‏\hadithno{34}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Ibn Shihab from Abu Idris al-Khawlani from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "The person doing wudu should snuff water up his nose and blow it out again}}
\hadithdefcmd{malik}{35}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عَبْدَ الرَّحْمَنِ بْنَ أَبِي بَكْرٍ، قَدْ دَخَلَ عَلَى عَائِشَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم يَوْمَ مَاتَ سَعْدُ بْنُ أَبِي وَقَّاصٍ فَدَعَا بِوَضُوءٍ فَقَالَتْ لَهُ عَائِشَةُ يَا عَبْدَ الرَّحْمَنِ أَسْبِغِ الْوُضُوءَ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ وَيْلٌ لِلأَعْقَابِ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{35}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya said that he heard Malik say that there was no harm in washing the mouth and cleaning the nose with only one handful of water. Yahya related to me from Malik that he had heard that Abd ar- Rahman ibn Abi Bakr was visiting A'isha, the wife of the Prophet, may AIIah bless him and grant him peace, on the day that Sad ibn Abi Waqqas died, and he asked for some water to do wudu. A'isha said to him, ''Abd ar-Rahman! Perform your wudu fully, for I heard the Messenger of Allah, may Allah bless him and grant him peace, say, 'Woe to the heels in the fire}}
\hadithdefcmd{malik}{36}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ مُحَمَّدِ بْنِ طَحْلاَءَ، عَنْ عُثْمَانَ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّ أَبَاهُ، حَدَّثَهُ أَنَّهُ، سَمِعَ عُمَرَ بْنَ الْخَطَّابِ، يَتَوَضَّأُ بِالْمَاءِ لِمَا تَحْتَ إِزَارِهِ ‏.‏ قَالَ يَحْيَى سُئِلَ مَالِكٌ عَنْ رَجُلٍ تَوَضَّأَ فَنَسِيَ فَغَسَلَ وَجْهَهُ قَبْلَ أَنْ يَتَمَضْمَضَ أَوْ غَسَلَ ذِرَاعَيْهِ قَبْلَ أَنْ يَغْسِلَ وَجْهَهُ فَقَالَ أَمَّا الَّذِي غَسَلَ وَجْهَهُ قَبْلَ أَنْ يَتَمَضْمَضَ فَلْيُمَضْمِضْ وَلاَ يُعِدْ غَسْلَ وَجْهِهِ وَأَمَّا الَّذِي غَسَلَ ذِرَاعَيْهِ قَبْلَ وَجْهِهِ فَلْيَغْسِلْ وَجْهَهُ ثُمَّ لِيُعِدْ غَسْلَ ذِرَاعَيْهِ حَتَّى يَكُونَ غَسْلُهُمَا بَعْدَ وَجْهِهِ إِذَا كَانَ ذَلِكَ فِي مَكَانِهِ أَوْ بِحَضْرَةِ ذَلِكَ ‏.‏ قَالَ يَحْيَى وَسُئِلَ مَالِكٌ عَنْ رَجُلٍ نَسِيَ أَنْ يَتَمَضْمَضَ وَيَسْتَنْثِرَ حَتَّى صَلَّى قَالَ لَيْسَ عَلَيْهِ أَنْ يُعِيدَ صَلاَتَهُ وَلْيُمَضْمِضْ وَيَسْتَنْثِرْ مَا يَسْتَقْبِلُ إِنْ كَانَ يُرِيدُ أَنْ يُصَلِّيَ ‏.‏\hadithno{36}\hadithgrade{Salim al-Hilali: Mauquf Hasan}\hadithtrans{Yahya related to me from Malik from Yahya ibn Muhammad ibn Talhafrom Uthman ibn Abd ar-Rahman that his father related to him that he had heard that Umar ibn al-Khattab used to wash what was beneath his waist wrapper with water. Yahya said that Malik was asked what a man should do if, when he did wudu, he forgot and washed his face before he had rinsed his mouth, or washed his forearms before he had washed his face. He said, "If someone washes his face before rinsing his mouth, he should rinse his mouth and not wash his face again. If someone washes his forearms before his face, however, he should wash his forearms again so that he has washed them after his face. This is if he is still near the place (of wudu)." Yahya said that Malik was asked about what a man should do if he had forgotten to rinse his mouth and nose until he had prayed, and he said, "He does not have to repeat the prayer, but should rinse his mouth and nose if he wishes to do any more prayers after that}}
\hadithdefcmd{malik}{37}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا اسْتَيْقَظَ أَحَدُكُمْ مِنْ نَوْمِهِ فَلْيَغْسِلْ يَدَهُ قَبْلَ أَنْ يُدْخِلَهَا فِي وَضُوئِهِ فَإِنَّ أَحَدَكُمْ لاَ يَدْرِي أَيْنَ بَاتَتْ يَدُهُ ‏"‏ ‏.‏\hadithno{37}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'zZinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "When you wake up from sleep to pray, wash your hands before you put them in the wudu water, for you do not know where your hands have spent the night}}
\hadithdefcmd{malik}{38}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، قَالَ إِذَا نَامَ أَحَدُكُمْ مُضْطَجِعًا فَلْيَتَوَضَّأْ ‏.‏\hadithno{38}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam that Umar ibn al-Khattab said, "If you fall asleep Iying down you must do wudu ( before you pray)}}
\hadithdefcmd{malik}{39}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، أَنَّ تَفْسِيرَ، هَذِهِ الآيَةِ ‏\{‏يَا أَيُّهَا الَّذِينَ آمَنُوا إِذَا قُمْتُمْ إِلَى الصَّلاَةِ فَاغْسِلُوا وُجُوهَكُمْ وَأَيْدِيَكُمْ إِلَى الْمَرَافِقِ وَامْسَحُوا بِرُءُوسِكُمْ وَأَرْجُلَكُمْ إِلَى الْكَعْبَيْنِ‏\}‏ أَنَّ ذَلِكَ إِذَا قُمْتُمْ مِنَ الْمَضَاجِعِ ‏.‏ يَعْنِي النَّوْمَ ‏.‏ قَالَ يَحْيَى قَالَ مَالِكٌ الأَمْرُ عِنْدَنَا أَنَّهُ لاَ يَتَوَضَّأُ مِنْ رُعَافٍ وَلاَ مِنْ دَمٍ وَلاَ مِنْ قَيْحٍ يَسِيلُ مِنَ الْجَسَدِ وَلاَ يَتَوَضَّأُ إِلاَّ مِنْ حَدَثٍ يَخْرُجُ مِنْ ذَكَرٍ أَوْ دُبُرٍ أَوْ نَوْمٍ ‏.‏\hadithno{39}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam that the ayat "You who believe! When you rise for prayer wash your faces, and your arms to the elbows, and wipe over your heads and your feet up to the ankles," refers to rising from bed, meaning sleep. Yahya said that Malik said, "The situation with us is that one does not have to do wudu for a nose-bleed, or for blood, or for pus issuing from the body. One only has to do wudu for impurities which issue from the genitals or the anus, or for sleep}}
\hadithdefcmd{malik}{40}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ ابْنَ عُمَرَ، كَانَ يَنَامُ جَالِسًا ثُمَّ يُصَلِّي وَلاَ يَتَوَضَّأُ ‏.‏\hadithno{40}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafithat Ibn Umar used to sleep sitting and then would pray without doing wudu}}
\hadithdefcmd{malik}{41}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ صَفْوَانَ بْنِ سُلَيْمٍ، عَنْ سَعِيدِ بْنِ سَلَمَةَ، - مِنْ آلِ بَنِي الأَزْرَقِ - عَنِ الْمُغِيرَةِ بْنِ أَبِي بُرْدَةَ، - وَهُوَ مِنْ بَنِي عَبْدِ الدَّارِ - أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ جَاءَ رَجُلٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنَّا نَرْكَبُ الْبَحْرَ وَنَحْمِلُ مَعَنَا الْقَلِيلَ مِنَ الْمَاءِ فَإِنْ تَوَضَّأْنَا بِهِ عَطِشْنَا أَفَنَتَوَضَّأُ بِهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ هُوَ الطَّهُورُ مَاؤُهُ الْحِلُّ مَيْتَتُهُ ‏"‏ ‏.‏\hadithno{41}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Safwan ibn Sulaym from Said ibn Salama of the Bani Azraq from al-Mughira ibn Abi Burda of the tribe of Bani Abd ad-Dar that he had heard Abu Hurayra speak about a man who came to the Messenger of Allah, may Allah bless him and grant him peace, and said, "Messenger of Allah! We travel by sea and we do not carry much fresh water with us so if we do wudu with it we go thirsty. Can we do wudu with seawater?" The Messenger of Allah, may Allah bless him and grant him peace, replied, "lts water is pure, and its dead creatures are halal}}
\hadithdefcmd{malik}{42}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ حُمَيْدَةَ بِنْتِ أَبِي عُبَيْدَةَ بْنِ فَرْوَةَ، عَنْ خَالَتِهَا، كَبْشَةَ بِنْتِ كَعْبِ بْنِ مَالِكٍ - وَكَانَتْ تَحْتَ ابْنِ أَبِي قَتَادَةَ الأَنْصَارِيِّ - أَنَّهَا أَخْبَرَتْهَا أَنَّ أَبَا قَتَادَةَ دَخَلَ عَلَيْهَا فَسَكَبَتْ لَهُ وَضُوءًا فَجَاءَتْ هِرَّةٌ لِتَشْرَبَ مِنْهُ فَأَصْغَى لَهَا الإِنَاءَ حَتَّى شَرِبَتْ قَالَتْ كَبْشَةُ فَرَآنِي أَنْظُرُ إِلَيْهِ فَقَالَ أَتَعْجَبِينَ يَا ابْنَةَ أَخِي قَالَتْ فَقُلْتُ نَعَمْ ‏.‏ فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّهَا لَيْسَتْ بِنَجَسٍ إِنَّمَا هِيَ مِنَ الطَّوَّافِينَ عَلَيْكُمْ أَوِ الطَّوَّافَاتِ ‏"‏ ‏.‏\hadithno{42}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ishaq ibn Abdullah ibn Abi Talha from Humayda bint Abi Ubayda ibn Farwa that her maternal aunt Kabsha bint Kab ibn Malik, who was the wife of the son of Abu Qatada al-Ansari, told her that once Abu Qatada was visiting her and she poured out some water for him to do wudu with. Just then a cat came to drink from it, so he tilted the vessel towards it to let it drink. Kabsha continued, "He saw me looking at him and said, 'Are you surprised, daughter of my brother?' I said, 'Yes.' He replied that the Messenger of Allah, may Allah bless him and grant him peace, said, cats are not impure. They intermingle with you .' " Yahya said that Malik said, "There is no harm in that unless one sees impurities on the cat's mouth}}
\hadithdefcmd{malik}{43}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ بْنِ الْحَارِثِ التَّيْمِيِّ، عَنْ يَحْيَى بْنِ عَبْدِ الرَّحْمَنِ بْنِ حَاطِبٍ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، خَرَجَ فِي رَكْبٍ فِيهِمْ عَمْرُو بْنُ الْعَاصِ حَتَّى وَرَدُوا حَوْضًا فَقَالَ عَمْرُو بْنُ الْعَاصِ لِصَاحِبِ الْحَوْضِ يَا صَاحِبَ الْحَوْضِ هَلْ تَرِدُ حَوْضَكَ السِّبَاعُ فَقَالَ عُمَرُ بْنُ الْخَطَّابِ يَا صَاحِبَ الْحَوْضِ لاَ تُخْبِرْنَا فَإِنَّا نَرِدُ عَلَى السِّبَاعِ وَتَرِدُ عَلَيْنَا ‏.‏\hadithno{43}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from Muhammad ibn Ibrahim ibn alHarith at-Taymi from Yahya ibn Abd ar-Rahman ibn Hatib that Umar ibn al-Khattab set out on one occasion with a party of riders, one of whom was Amr ibn al-As. They came to a watering place and Amr ibn al-As asked the man who owned it whether wild beasts drank from it. Umar ibn al-Khattab told the owner of the watering place not to answer, since the people drank after the wild beasts and the wild beasts drank after them}}
\hadithdefcmd{malik}{44}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَقُولُ إِنْ كَانَ الرِّجَالُ وَالنِّسَاءُ فِي زَمَانِ رَسُولِ اللَّهِ صلى الله عليه وسلم لَيَتَوَضَّئُونَ جَمِيعًا ‏.‏\hadithno{44}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to say that men and their wives used to do wudu together in the time of the Messenger of Allah}}
\hadithdefcmd{malik}{45}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ مُحَمَّدِ بْنِ عُمَارَةَ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ أُمِّ وَلَدٍ، لإِبْرَاهِيمَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ أَنَّهَا سَأَلَتْ أُمَّ سَلَمَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم فَقَالَتْ إِنِّي امْرَأَةٌ أُطِيلُ ذَيْلِي وَأَمْشِي فِي الْمَكَانِ الْقَذِرِ قَالَتْ أُمُّ سَلَمَةَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يُطَهِّرُهُ مَا بَعْدَهُ ‏"‏ ‏.‏\hadithno{45}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Muhammad ibn Umara from Muhammad ibn Ibrahim that the mother of the son of Ibrahim ibn Abd ar- Rahman ibn Awf questioned Umm Salama, the wife of the Prophet, may Allah bless him and grant him peace, and said, "I am a woman who wears a long skirt and (sometimes) I walk in dirty places." Umm Salama replied, "The Messenger of Allah, may Allah bless him and grant him peace, said, 'What follows (i.e. clean places) purifies it}}
\hadithdefcmd{malik}{46}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ رَأَى رَبِيعَةَ بْنَ أَبِي عَبْدِ الرَّحْمَنِ يَقْلِسُ مِرَارًا وَهُوَ فِي الْمَسْجِدِ فَلاَ يَنْصَرِفُ وَلاَ يَتَوَضَّأُ حَتَّى يُصَلِّيَ ‏.‏ قَالَ يَحْيَى وَسُئِلَ مَالِكٌ عَنْ رَجُلٍ قَلَسَ طَعَامًا هَلْ عَلَيْهِ وُضُوءٌ فَقَالَ لَيْسَ عَلَيْهِ وُضُوءٌ وَلْيَتَمَضْمَضْ مِنْ ذَلِكَ وَلْيَغْسِلْ فَاهُ ‏.‏\hadithno{46}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that he saw Rabia ibn Abd ar- Rahman vomit several times when he was in the mosque and he did not leave, nor did he do wudu before he prayed. Yahya said that Malik was asked whether a man who vomited food had to do wudu and he said, "He does not have to do wudu, but he should rinse the inside of his mouth and wash his mouth out}}
\hadithdefcmd{malik}{47}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، حَنَّطَ ابْنًا لِسَعِيدِ بْنِ زَيْدٍ وَحَمَلَهُ ثُمَّ دَخَلَ الْمَسْجِدَ فَصَلَّى وَلَمْ يَتَوَضَّأْ ‏.‏ قَالَ يَحْيَى وَسُئِلَ مَالِكٌ هَلْ فِي الْقَىْءِ وُضُوءٌ قَالَ لاَ وَلَكِنْ لِيَتَمَضْمَضْ مِنْ ذَلِكَ وَلْيَغْسِلْ فَاهُ وَلَيْسَ عَلَيْهِ وُضُوءٌ ‏.‏\hadithno{47}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar prepared the body of one of Said ibn Zayd's sons for burial and carried it and then entered the mosque and prayed without doing wudu. Yahya said that Malik was asked whether it was necessary to do wudu because of regurgitating undigested food and he said, "No, wudu is not necessary, but the mouth should be rinsed}}
\hadithdefcmd{malik}{48}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، ‏.‏ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَكَلَ كَتِفَ شَاةٍ ثُمَّ صَلَّى وَلَمْ يَتَوَضَّأْ ‏.‏\hadithno{48}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Zayd Aslam from Ata ibn Yasar from Abdullah Abbas that the Messenger of Allah, may Allah bless him and grant him peace, ate a shoulder of lamb and then prayed without doing wudu}}
\hadithdefcmd{malik}{49}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ بُشَيْرِ بْنِ يَسَارٍ، مَوْلَى بَنِي حَارِثَةَ عَنْ سُوَيْدِ بْنِ النُّعْمَانِ، أَنَّهُ أَخْبَرَهُ أَنَّهُ، خَرَجَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَامَ خَيْبَرَ حَتَّى إِذَا كَانُوا بِالصَّهْبَاءِ - وَهِيَ مِنْ أَدْنَى خَيْبَرَ - نَزَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَصَلَّى الْعَصْرَ ثُمَّ دَعَا بِالأَزْوَادِ فَلَمْ يُؤْتَ إِلاَّ بِالسَّوِيقِ فَأَمَرَ بِهِ فَثُرِّيَ فَأَكَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَكَلْنَا ثُمَّ قَامَ إِلَى الْمَغْرِبِ فَمَضْمَضَ وَمَضْمَضْنَا ثُمَّ صَلَّى وَلَمْ يَتَوَضَّأْ ‏.‏\hadithno{49}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from Bushayr ibn Yasar, the mawla of the Bani Haritha, that Suwayd ibn anNuman told him that he went with the Messenger of Allah, may Allah bless him and grant him peace, on the expedition to Khaybar. When they reached as Suhba, which was near Khaybar, the Messenger of Allah, may Allah bless him and grant him peace, stopped and prayed asr. He asked for provisions but only parched barley was brought, so he asked for it to be moistened. The Messenger of Allah, may Allah bless him and grant him peace, ate and the people ate with him. Then he got up to do maghrib and rinsed his mouth out and they rinsed out theirs. Then he prayed without doing wudu}}
\hadithdefcmd{malik}{50}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، وَعَنْ صَفْوَانَ بْنِ سُلَيْمٍ، أَنَّهُمَا أَخْبَرَاهُ عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ بْنِ الْحَارِثِ التَّيْمِيِّ، عَنْ رَبِيعَةَ بْنِ عَبْدِ اللَّهِ بْنِ الْهُدَيْرِ، أَنَّهُ تَعَشَّى مَعَ عُمَرَ بْنِ الْخَطَّابِ ثُمَّ صَلَّى وَلَمْ يَتَوَضَّأْ ‏.‏\hadithno{50}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that both Muhammad ibn al-Munkadir and Safwan ibn Sulaym transmitted to him from Muhammad ibn Ibrahim ibn al-Harith at-Taymi from Rabia ibn Abdullah ibn al-Hudayr that he had eaten an evening meal with Umar ibn al-Khattab who then prayed without doing wudu}}
\hadithdefcmd{malik}{51}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ ضَمْرَةَ بْنِ سَعِيدٍ الْمَازِنِيِّ، عَنْ أَبَانَ بْنِ عُثْمَانَ، أَنَّ عُثْمَانَ بْنَ عَفَّانَ، أَكَلَ خُبْزًا وَلَحْمًا ثُمَّ مَضْمَضَ وَغَسَلَ يَدَيْهِ وَمَسَحَ بِهِمَا وَجْهَهُ ثُمَّ صَلَّى وَلَمْ يَتَوَضَّأْ ‏.‏\hadithno{51}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Damra ibn Said al-Mazini from Aban ibn Uthman that Uthman ibn Affan ate bread and meat, rinsed his mouth out, washed his hands and wiped his face with them, and then prayed without doing wudu}}
\hadithdefcmd{malik}{52}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عَلِيَّ بْنَ أَبِي طَالِبٍ، وَعَبْدَ اللَّهِ بْنَ عَبَّاسٍ، كَانَا لاَ يَتَوَضَّآنِ مِمَّا مَسَّتِ النَّارُ ‏.‏\hadithno{52}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that he had heard that Ali ibn Abi Talib and Abdullah ibn Abbas did not do wudu after eating cooked food}}
\hadithdefcmd{malik}{53}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ سَأَلَ عَبْدَ اللَّهِ بْنَ عَامِرِ بْنِ رَبِيعَةَ عَنِ الرَّجُلِ، يَتَوَضَّأُ لِلصَّلاَةِ ثُمَّ يُصِيبُ طَعَامًا قَدْ مَسَّتْهُ النَّارُ أَيَتَوَضَأُ قَالَ رَأَيْتُ أَبِي يَفْعَلُ ذَلِكَ وَلاَ يَتَوَضَّأُ ‏.‏\hadithno{53}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that he asked Abdullah ibn Amir ibn Rabia whether a man who did wudu for prayer and then ate cooked food had to do wudu again. He said, "I saw my father do that without doing wudu}}
\hadithdefcmd{malik}{54}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ أَبِي نُعَيْمٍ، وَهْبِ بْنِ كَيْسَانَ أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ الأَنْصَارِيَّ، يَقُولُ رَأَيْتُ أَبَا بَكْرٍ الصِّدِّيقَ أَكَلَ لَحْمًا ثُمَّ صَلَّى وَلَمْ يَتَوَضَّأْ ‏.‏\hadithno{54}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Abu Nuaym Wahb ibn Kaysan that he heard Jabir ibn Abdullah al-Ansari saying, "I saw Abu Bakr as- Siddiq eat meat and then pray without doing wudu}}
\hadithdefcmd{malik}{55}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دُعِيَ لِطَعَامٍ فَقُرِّبَ إِلَيْهِ خُبْزٌ وَلَحْمٌ فَأَكَلَ مِنْهُ ثُمَّ تَوَضَّأَ وَصَلَّى ثُمَّ أُتِيَ بِفَضْلِ ذَلِكَ الطَّعَامِ فَأَكَلَ مِنْهُ ثُمَّ صَلَّى وَلَمْ يَتَوَضَّأْ ‏.‏\hadithno{55}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Muhammad ibn al-Munkadir that the Messenger of Allah, may Allah bless him and grant him peace, was invited to eat, and some bread and meat was brought to him. He ate some of it, and then did wudu and prayed. Then more of the same food was brought and he ate some more and then prayed without doing wudu}}
\hadithdefcmd{malik}{56}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ زَيْدٍ الأَنْصَارِيِّ، أَنَّ أَنَسَ بْنَ مَالِكٍ، قَدِمَ مِنَ الْعِرَاقِ فَدَخَلَ عَلَيْهِ أَبُو طَلْحَةَ وَأُبَىُّ بْنُ كَعْبٍ فَقَرَّبَ لَهُمَا طَعَامًا قَدْ مَسَّتْهُ النَّارُ فَأَكَلُوا مِنْهُ فَقَامَ أَنَسٌ فَتَوَضَّأَ فَقَالَ أَبُو طَلْحَةَ وَأُبَىُّ بْنُ كَعْبٍ مَا هَذَا يَا أَنَسُ أَعِرَاقِيَّةٌ فَقَالَ أَنَسٌ لَيْتَنِي لَمْ أَفْعَلْ ‏.‏ وَقَامَ أَبُو طَلْحَةَ وَأُبَىُّ بْنُ كَعْبٍ فَصَلَّيَا وَلَمْ يَتَوَضَّآ ‏.‏\hadithno{56}\hadithgrade{Salim al-Hilali: Mauquf Hasan}\hadithtrans{It was related to me from Malik from Musa ibn Uqba from Abd ar- Rahman ibn Yazid al-Ansari that when Anas ibn Malik came back from Iraq, Abu Talha and Ubayy ibn Kab visited him. He brought them some cooked food and they ate, and then Anas got up and did wudu. Abu Talha and Ubayy ibn Kab asked, "What's this, Anas? Is it an Iraqi custom?" and Anas said, "I wish I had not done it." (i.e. wudu). Abu Talha and Ubayy ibn Kab both got up and prayed without doing wudu}}
\hadithdefcmd{malik}{57}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سُئِلَ عَنْ الاِسْتِطَابَةِ فَقَالَ ‏ "‏ أَوَلاَ يَجِدُ أَحَدُكُمْ ثَلاَثَةَ أَحْجَارٍ ‏"‏ ‏.‏\hadithno{57}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father that the Messenger of Allah, may Allah bless him and grant him peace, was asked about cleaning after excretion. He replied, "Are any of you unable to find three stones?}}
\hadithdefcmd{malik}{58}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ إِلَى الْمَقْبُرَةِ فَقَالَ ‏"‏ السَّلاَمُ عَلَيْكُمْ دَارَ قَوْمٍ مُؤْمِنِينَ وَإِنَّا إِنْ شَاءَ اللَّهُ بِكُمْ لاَحِقُونَ وَدِدْتُ أَنِّي قَدْ رَأَيْتُ إِخْوَانَنَا ‏"‏ ‏.‏ فَقَالُوا يَا رَسُولَ اللَّهِ أَلَسْنَا بِإِخْوَانِكَ قَالَ ‏"‏ بَلْ أَنْتُمْ أَصْحَابِي وَإِخْوَانُنَا الَّذِينَ لَمْ يَأْتُوا بَعْدُ وَأَنَا فَرَطُهُمْ عَلَى الْحَوْضِ ‏"‏ ‏.‏ فَقَالُوا يَا رَسُولَ اللَّهِ كَيْفَ تَعْرِفُ مَنْ يَأْتِي بَعْدَكَ مِنْ أُمَّتِكَ قَالَ ‏"‏ أَرَأَيْتَ لَوْ كَانَ لِرَجُلٍ خَيْلٌ غُرٌّ مُحَجَّلَةٌ فِي خَيْلٍ دُهْمٍ بُهْمٍ أَلاَ يَعْرِفُ خَيْلَهُ ‏"‏ ‏.‏ قَالُوا بَلَى يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ فَإِنَّهُمْ يَأْتُونَ يَوْمَ الْقِيَامَةِ غُرًّا مُحَجَّلِينَ مِنَ الْوُضُوءِ وَأَنَا فَرَطُهُمْ عَلَى الْحَوْضِ فَلاَ يُذَادَنَّ رِجَالٌ عَنْ حَوْضِي كَمَا يُذَادُ الْبَعِيرُ الضَّالُّ أُنَادِيهِمْ أَلاَ هَلُمَّ أَلاَ هَلُمَّ أَلاَ هَلُمَّ فَيُقَالُ إِنَّهُمْ قَدْ بَدَّلُوا بَعْدَكَ فَأَقُولُ فَسُحْقًا فَسُحْقًا فَسُحْقًا ‏"‏ ‏.‏\hadithno{58}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from al-Ala ibn Abd ar-Rahman from his father from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, went to the burial grounds and said, "Peace be upon you, home of a people who believe! We shall be among you, Allah willing. I wish that I had seen our brothers!" The people with him said, "Messenger of Allah! Are we not your brothers?" "No," he said, "You are my companions. Our brothers are those who have not yet come. And I will precede them to the Hawd. (The Hawd:the watering place of the Prophet, may Allah bless him and grant him peace, from which he will give to the people of his community on the day of rising.)" They asked him, "Messenger of Allah! How will you recognise those of your community who come after you?" He said, "Doesn't a man who has horses with white legs and white blazes on their foreheads among totally black horses recognise which ones are his own?" They said, "Of course, Messenger of Allah." He went on, "Even so will they come on the day of rising with white marks on their foreheads, hands and feet from wudu, and I will precede them to the Hawd. Some men will be driven away from the Hawd as if they were straying camels and I shall call out to them, 'Will you not come? Will you not come? Will you not come?' and someone will say, 'They changed things after you,' so I shall say, 'Then away with them, away with them, away with them}}
\hadithdefcmd{malik}{59}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ حُمْرَانَ، مَوْلَى عُثْمَانَ بْنِ عَفَّانَ أَنَّ عُثْمَانَ بْنَ عَفَّانَ، جَلَسَ عَلَى الْمَقَاعِدِ فَجَاءَ الْمُؤَذِّنُ فَآذَنَهُ بِصَلاَةِ الْعَصْرِ فَدَعَا بِمَاءٍ فَتَوَضَّأَ ثُمَّ قَالَ وَاللَّهِ لأُحَدِّثَنَّكُمْ حَدِيثًا لَوْلاَ أَنَّهُ فِي كِتَابِ اللَّهِ مَا حَدَّثْتُكُمُوهُ ثُمَّ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا مِنِ امْرِئٍ يَتَوَضَّأُ فَيُحْسِنُ وُضُوءَهُ ثُمَّ يُصَلِّي الصَّلاَةَ إِلاَّ غُفِرَ لَهُ مَا بَيْنَهُ وَبَيْنَ الصَّلاَةِ الأُخْرَى حَتَّى يُصَلِّيَهَا ‏"‏ ‏.‏\hadithno{59}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father from Humran, the mawla of Uthman ibn Affan, that Uthman ibn Affan was once sitting on the Maqaid (the benches surrounding the Madina Mosque, or else a stone near Uthman ibn Affan's house where he sat to discuss with people), when the muadhdhin came and told him that it was time for the asr prayer. He called for water and did wudu. Then he said, "By Allah, I shall tell you something which I would not tell you if it were not in the Book of Allah. I heard the Messenger of Allah, may Allah bless him and grant him peace, say, 'If a man does wudu, and makes sure he does it correctly, and then does the prayer, he will be forgiven everything that he does between then and the time when he prays the next prayer.' " Yahya said that Malik said, "I believe he meant this ayat - 'Establish prayer at the two ends of the day and in some watches of the night. Good actions take away wrong actions. That is a reminder for those who remember.' " (Sura 11 ayat)}}
\hadithdefcmd{malik}{60}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ عَبْدِ اللَّهِ الصُّنَابِحِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا تَوَضَّأَ الْعَبْدُ الْمُؤْمِنُ فَتَمَضْمَضَ خَرَجَتِ الْخَطَايَا مِنْ فِيهِ وَإِذَا اسْتَنْثَرَ خَرَجَتِ الْخَطَايَا مِنْ أَنْفِهِ فَإِذَا غَسَلَ وَجْهَهُ خَرَجَتِ الْخَطَايَا مِنْ وَجْهِهِ حَتَّى تَخْرُجَ مِنْ تَحْتِ أَشْفَارِ عَيْنَيْهِ فَإِذَا غَسَلَ يَدَيْهِ خَرَجَتِ الْخَطَايَا مِنْ يَدَيْهِ حَتَّى تَخْرُجَ مِنْ تَحْتِ أَظْفَارِ يَدَيْهِ فَإِذَا مَسَحَ بِرَأْسِهِ خَرَجَتِ الْخَطَايَا مِنْ رَأْسِهِ حَتَّى تَخْرُجَ مِنْ أُذُنَيْهِ فَإِذَا غَسَلَ رِجْلَيْهِ خَرَجَتِ الْخَطَايَا مِنْ رِجْلَيْهِ حَتَّى تَخْرُجَ مِنْ تَحْتِ أَظْفَارِ رِجْلَيْهِ - قَالَ - ثُمَّ كَانَ مَشْيُهُ إِلَى الْمَسْجِدِ وَصَلاَتُهُ نَافِلَةً لَهُ ‏"‏ ‏.‏\hadithno{60}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam from Ata ibn Yasar from Abdullah as-Sanabihi that the Messenger of Allah, may Allah bless him and grant him peace, said, "A trusting slave does wudu and as he rinses his mouth the wrong actions leave it. As he cleans his nose the wrong actions leave it. As he washes his face, the wrong actions leave it, even from underneath his eyelashes. As he washes his hands the wrong actions leave them, even from underneath his fingernails. As he wipes his head the wrong actions leave it, even from his ears. And as he washes his feet the wrong actions leave them, even from underneath the toenails of both his feet." He added, "Then his walking to the mosque and his prayer are an extra reward for him}}
\hadithdefcmd{malik}{61}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا تَوَضَّأَ الْعَبْدُ الْمُسْلِمُ - أَوِ الْمُؤْمِنُ - فَغَسَلَ وَجْهَهُ خَرَجَتْ مِنْ وَجْهِهِ كُلُّ خَطِيئَةٍ نَظَرَ إِلَيْهَا بِعَيْنَيْهِ مَعَ الْمَاءِ - أَوْ مَعَ آخِرِ قَطْرِ الْمَاءِ - فَإِذَا غَسَلَ يَدَيْهِ خَرَجَتْ مِنْ يَدَيْهِ كُلُّ خَطِيئَةٍ بَطَشَتْهَا يَدَاهُ مَعَ الْمَاءِ - أَوْ مَعَ آخِرِ قَطْرِ الْمَاءِ فَإِذَا غَسَلَ رِجْلَيْهِ خَرَجَتْ كُلُّ خَطِيئَةٍ مَشَتْهَا رِجْلاَهُ مَعَ الْمَاءِ - أَوْ مَعَ آخِرِ قَطْرِ الْمَاءِ - حَتَّى يَخْرُجَ نَقِيًّا مِنَ الذُّنُوبِ ‏"‏ ‏.‏\hadithno{61}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Suhayl ibn Abi Salih from his father from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "A muslim slave (or a trusting slave) does wudu and as he washes his face every wrong action he has seen with his eyes leaves with the water (or the last drop of water). As he washes his hands every wrong action he has done with his hands leaves with the water (orthe last drop of water). And as he washes his feet every wrong action his feet have walked to leaves with the water (or the last drop of water) so that he comes away purified of wrong actions}}
\hadithdefcmd{malik}{62}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّهُ قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَحَانَتْ صَلاَةُ الْعَصْرِ فَالْتَمَسَ النَّاسُ وَضُوءًا فَلَمْ يَجِدُوهُ فَأُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِوَضُوءٍ فِي إِنَاءٍ فَوَضَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي ذَلِكَ الإِنَاءِ يَدَهُ ثُمَّ أَمَرَ النَّاسَ يَتَوَضَّئُونَ مِنْهُ - قَالَ أَنَسٌ - فَرَأَيْتُ الْمَاءَ يَنْبُعُ مِنْ تَحْتِ أَصَابِعِهِ فَتَوَضَّأَ النَّاسُ حَتَّى تَوَضَّئُوا مِنْ عِنْدِ آخِرِهِمْ ‏.‏\hadithno{62}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ishaq ibn Abdullah ibn Abi Talha that Anas ibn Malik said, "I saw the Messenger of Allah, may Allah bless him and grant him peace, on one occasion when the asr prayer was at hand . Everyone was looking for water for wudu but no- one could find any. Then the Messenger of Allah, may Allah bless him and grant him peace, brought some water in a vessel . He put his hand into the vessel and then he told them all to do wudu from it." Anas added, "I saw water coming out from his fingers. Then all of them to the last man did wudu}}
\hadithdefcmd{malik}{63}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نُعَيْمِ بْنِ عَبْدِ اللَّهِ الْمَدَنِيِّ الْمُجْمِرِ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ مَنْ تَوَضَّأَ فَأَحْسَنَ وُضُوءَهُ ثُمَّ خَرَجَ عَامِدًا إِلَى الصَّلاَةِ فَإِنَّهُ فِي صَلاَةٍ مَادَامَ يَعْمِدُ إِلَى الصَّلاَةِ وَإِنَّهُ يُكْتَبُ لَهُ بِإِحْدَى خُطْوَتَيْهِ حَسَنَةٌ وَيُمْحَى عَنْهُ بِالأُخْرَى سَيِّئَةٌ فَإِذَا سَمِعَ أَحَدُكُمُ الإِقَامَةَ فَلاَ يَسْعَ فَإِنَّ أَعْظَمَكُمْ أَجْرًا أَبْعَدُكُمْ دَارًا ‏.‏ قَالُوا لِمَ يَا أَبَا هُرَيْرَةَ قَالَ مِنْ أَجْلِ كَثْرَةِ الْخُطَا ‏.‏\hadithno{63}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nuaym ibn Abdullah al-Madani al-Mujmir that he heard Abu Hurayra say, "If someone does wudu and does it correctly and then goes off intending to do the prayer, then he is in prayer as long as he intends to do the prayer. A good action is written for every alternate step he makes and a wrong action is erased for the second. When you hear the iqama do not lengthen your stride, and the one who has the greatest reward is the one whose house is farthest away." They said, "Why, Abu Hurayra?" He replied, "Because of the greater number of steps}}
\hadithdefcmd{malik}{64}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ سَمِعَ سَعِيدَ بْنَ الْمُسَيَّبِ، يُسْأَلُ عَنِ الْوُضُوءِ، مِنَ الْغَائِطِ بِالْمَاءِ فَقَالَ سَعِيدٌ إِنَّمَا ذَلِكَ وُضُوءُ النِّسَاءِ ‏.‏\hadithno{64}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that he heard someone ask Said ibn al-Musayyab about washing off excreta with water. Said said, "That is the way women wash}}
\hadithdefcmd{malik}{65}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا شَرِبَ الْكَلْبُ فِي إِنَاءِ أَحَدِكُمْ فَلْيَغْسِلْهُ سَبْعَ مَرَّاتٍ ‏"‏ ‏.‏\hadithno{65}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z-Zinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "If a dog drinks from your vessel, wash it seven times}}
\hadithdefcmd{malik}{66}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ اسْتَقِيمُوا وَلَنْ تُحْصُوا وَاعْمَلُوا وَخَيْرُ أَعْمَالِكُمُ الصَّلاَةُ وَلاَ يُحَافِظُ عَلَى الْوُضُوءِ إِلاَّ مُؤْمِنٌ ‏"‏ ‏.‏\hadithno{66}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik that he had heard that the Messenger of Allah, may Allah bless him and grant him peace, said, "Try to go straight, although you will not be able to do so. Act, and the best of your actions is the prayer. And only a mumin is constant in his wudu}}
\hadithdefcmd{malik}{67}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَأْخُذُ الْمَاءَ بِأَصْبُعَيْهِ لأُذُنَيْهِ ‏.‏\hadithno{67}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar used two fingers to take water to his ears}}
\hadithdefcmd{malik}{68}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ جَابِرَ بْنَ عَبْدِ اللَّهِ الأَنْصَارِيَّ، سُئِلَ عَنِ الْمَسْحِ، عَلَى الْعِمَامَةِ فَقَالَ لاَ حَتَّى يُمْسَحَ الشَّعْرُ بِالْمَاءِ ‏.‏\hadithno{68}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Jabir ibn Abdullah al-Ansari was asked about wiping over a turban. He said, "Not unless you have wiped over your hair with water}}
\hadithdefcmd{malik}{69}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، أَنَّ أَبَاهُ، عُرْوَةَ بْنَ الزُّبَيْرِ كَانَ يَنْزِعُ الْعِمَامَةَ وَيَمْسَحُ رَأْسَهُ بِالْمَاءِ ‏.‏\hadithno{69}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa that Abu Urwa ibn az-Zubayr used to take off his turban and wipe his head with water}}
\hadithdefcmd{malik}{70}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّهُ رَأَى صَفِيَّةَ بِنْتَ أَبِي عُبَيْدٍ امْرَأَةَ عَبْدِ اللَّهِ بْنِ عُمَرَ تَنْزِعُ خِمَارَهَا وَتَمْسَحُ عَلَى رَأْسِهَا بِالْمَاءِ وَنَافِعٌ يَوْمَئِذٍ صَغِيرٌ ‏.‏ وَسُئِلَ مَالِكٌ عَنِ الْمَسْحِ عَلَى الْعِمَامَةِ وَالْخِمَارِ فَقَالَ لاَ يَنْبَغِي أَنْ يَمْسَحَ الرَّجُلُ وَلاَ الْمَرْأَةُ عَلَى عِمَامَةٍ وَلاَ خِمَارٍ وَلْيَمْسَحَا عَلَى رُءُوسِهِمَا ‏.‏ وَسُئِلَ مَالِكٌ عَنْ رَجُلٍ تَوَضَّأَ فَنَسِيَ أَنْ يَمْسَحَ عَلَى رَأْسِهِ حَتَّى جَفَّ وَضُوءُهُ قَالَ أَرَى أَنْ يَمْسَحَ بِرَأْسِهِ وَإِنْ كَانَ قَدْ صَلَّى أَنْ يُعِيدَ الصَّلاَةَ ‏.‏\hadithno{70}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that she saw Safiyya bint Abi Ubayd, the wife of Abdullah ibn 'Umar, take off her head- covering and wipe her head with water. Nafi was a child at the time. Malik was asked about a man who did wudu but forgot to wipe his head until the water had dried. He said, "I consider that he should wipe his head and then repeat the prayer if he has already performed it." Malik was asked about a man who did wudu but forgot to wipe his head until the water had dried. He said, "I consider that he should wipe his head and then repeat the prayer if he has already performed it}}
\hadithdefcmd{malik}{71}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَبَّادِ بْنِ زِيَادٍ، مِنْ وَلَدِ الْمُغِيرَةِ بْنِ شُعْبَةَ عَنْ أَبِيهِ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم ذَهَبَ لِحَاجَتِهِ فِي غَزْوَةِ تَبُوكَ - قَالَ الْمُغِيرَةُ - فَذَهَبْتُ مَعَهُ بِمَاءٍ فَجَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَسَكَبْتُ عَلَيْهِ الْمَاءَ فَغَسَلَ وَجْهَهُ ثُمَّ ذَهَبَ يُخْرِجُ يَدَيْهِ مِنْ كُمَّىْ جُبَّتِهِ فَلَمْ يَسْتَطِعْ مِنْ ضِيقِ كُمَّىِ الْجُبَّةِ فَأَخْرَجَهُمَا مِنْ تَحْتِ الْجُبَّةِ فَغَسَلَ يَدَيْهِ وَمَسَحَ بِرَأْسِهِ وَمَسَحَ عَلَى الْخُفَّيْنِ فَجَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَعَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ يَؤُمُّهُمْ وَقَدْ صَلَّى بِهِمْ رَكْعَةً فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم الرَّكْعَةَ الَّتِي بَقِيَتْ عَلَيْهِمْ فَفَزِعَ النَّاسُ فَلَمَّا قَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَحْسَنْتُمْ ‏"‏ ‏.‏\hadithno{71}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Abbad ibn Ziyad, a descendant of al-Mughira ibn Shuba from his father from al Mughira ibn Shuba that the Messenger of Allah, may Allah bless him and grant him peace, went to relieve himself during the expedition of Tabuk. Mughira said, "I went with him, taking water. Then the Messenger of Allah, may Allah bless him and grant him peace, came back and I poured out the water for him. He washed his hands and then went to push his hands out of the sleeves of his garment, but could not do so because of their narrowness. So he brought them out from underneath his garment. Then he washed his arms, wiped his head and wiped over his leather socks. The Messenger of Allah, may Allah bless him and grant him peace, returned and Abdar Rahman ibn Awf was leading the people in prayer, and he had already finished one raka with them. The Messenger of Allah, may Allah bless him and grant him peace, prayed the remaining raka with them to everyone's concern. When the Messenger of Allah, may Allah bless him and grant him peace, finished he said, 'You have acted correctly}}
\hadithdefcmd{malik}{72}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، وَعَبْدِ اللَّهِ بْنِ دِينَارٍ، أَنَّهُمَا أَخْبَرَاهُ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ قَدِمَ الْكُوفَةَ عَلَى سَعْدِ بْنِ أَبِي وَقَّاصٍ وَهُوَ أَمِيرُهَا فَرَآهُ عَبْدُ اللَّهِ بْنُ عُمَرَ يَمْسَحُ عَلَى الْخُفَّيْنِ فَأَنْكَرَ ذَلِكَ عَلَيْهِ فَقَالَ لَهُ سَعْدٌ سَلْ أَبَاكَ إِذَا قَدِمْتَ عَلَيْهِ فَقَدِمَ عَبْدُ اللَّهِ فَنَسِيَ أَنْ يَسْأَلَ عُمَرَ عَنْ ذَلِكَ حَتَّى قَدِمَ سَعْدٌ فَقَالَ أَسَأَلْتَ أَبَاكَ فَقَالَ لاَ ‏.‏ فَسَأَلَهُ عَبْدُ اللَّهِ فَقَالَ عُمَرُ إِذَا أَدْخَلْتَ رِجْلَيْكَ فِي الْخُفَّيْنِ وَهُمَا طَاهِرَتَانِ فَامْسَحْ عَلَيْهِمَا ‏.‏ قَالَ عَبْدُ اللَّهِ وَإِنْ جَاءَ أَحَدُنَا مِنَ الْغَائِطِ فَقَالَ عُمَرُ نَعَمْ وَإِنْ جَاءَ أَحَدُكُمْ مِنَ الْغَائِطِ ‏.‏\hadithno{72}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that Nafi and Abdullah ibn Dinar told him that Abdullah ibn Umar arrived at Kufa and went to Sad ibn Abi Waqqas, who was the Amir of Kufa at that time. Abdullah ibn Umar saw him wiping over his leather socks and disapproved of it. So Sad said to him, "Ask your father when you get back." Abdullah returned but forgot to ask Umar about the matter until Sad arrived and said, "Have you asked your father?" and he said, "No." Abdullah then asked Umar and Umar replied, "If your feet are ritually pure when you put them in the leather socks then you can wipe over the socks." Abdullah said ,"What about if we have just come from relieving ourselves?" Umar said, "Yes, even if you have just come from relieving yourself}}
\hadithdefcmd{malik}{73}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، بَالَ فِي السُّوقِ ثُمَّ تَوَضَّأَ فَغَسَلَ وَجْهَهُ وَيَدَيْهِ وَمَسَحَ رَأْسَهُ ثُمَّ دُعِيَ لِجَنَازَةٍ لِيُصَلِّيَ عَلَيْهَا حِينَ دَخَلَ الْمَسْجِدَ فَمَسَحَ عَلَى خُفَّيْهِ ثُمَّ صَلَّى عَلَيْهَا ‏.‏\hadithno{73}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar urinated in the market place and then did wudu, washing his face and hands and wiping his head. Then as soon as he had come into the mosque, he was called to pray over a dead person, so he wiped over his leather socks and prayed}}
\hadithdefcmd{malik}{74}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ سَعِيدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ رُقَيْشٍ، أَنَّهُ قَالَ رَأَيْتُ أَنَسَ بْنَ مَالِكٍ أَتَى قُبَا فَبَالَ ثُمَّ أُتِيَ بِوَضُوءٍ فَتَوَضَّأَ فَغَسَلَ وَجْهَهُ وَيَدَيْهِ إِلَى الْمِرْفَقَيْنِ وَمَسَحَ بِرَأْسِهِ وَمَسَحَ عَلَى الْخُفَّيْنِ ثُمَّ جَاءَ الْمَسْجِدَ فَصَلَّى ‏.‏ قَالَ يَحْيَى وَسُئِلَ مَالِكٌ عَنْ رَجُلٍ تَوَضَّأَ وُضُوءَ الصَّلاَةِ ثُمَّ لَبِسَ خُفَّيْهِ ثُمَّ بَالَ ثُمَّ نَزَعَهُمَا ثُمَّ رَدَّهُمَا فِي رِجْلَيْهِ أَيَسْتَأْنِفُ الْوُضُوءَ فَقَالَ لِيَنْزِعْ خُفَّيْهِ وَلْيَغْسِلْ رِجْلَيْهِ وَإِنَّمَا يَمْسَحُ عَلَى الْخُفَّيْنِ مَنْ أَدْخَلَ رِجْلَيْهِ فِي الْخُفَّيْنِ وَهُمَا طَاهِرَتَانِ بِطُهْرِ الْوُضُوءِ وَأَمَّا مَنْ أَدْخَلَ رِجْلَيْهِ فِي الْخُفَّيْنِ وَهُمَا غَيْرُ طَاهِرَتَيْنِ بِطُهْرِ الْوُضُوءِ فَلاَ يَمْسَحْ عَلَى الْخُفَّيْنِ ‏.‏ قَالَ وَسُئِلَ مَالِكٌ عَنْ رَجُلٍ تَوَضَّأَ وَعَلَيْهِ خُفَّاهُ فَسَهَا عَنِ الْمَسْحِ عَلَى الْخُفَّيْنِ حَتَّى جَفَّ وَضُوءُهُ وَصَلَّى قَالَ لِيَمْسَحْ عَلَى خُفَّيْهِ وَلْيُعِدِ الصَّلاَةَ وَلاَ يُعِيدُ الْوُضُوءَ ‏.‏ وَسُئِلَ مَالِكٌ عَنْ رَجُلٍ غَسَلَ قَدَمَيْهِ ثُمَّ لَبِسَ خُفَّيْهِ ثُمَّ اسْتَأْنَفَ الْوُضُوءَ فَقَالَ لِيَنْزِعْ خُفَّيْهِ ثُمَّ لْيَتَوَضَّأْ وَلْيَغْسِلْ رِجْلَيْهِ ‏.‏\hadithno{74}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that Said ibn Abd ar-Rahman ibn Ruqash said, "I saw Anas ibn Malik come and squat and urinate.Then water was brought and he did wudu. He washed his face, then his arms to the elbows, and then he wiped his head and wiped over his leather socks. Then he came to the mosque and prayed." Yahya said that Malik was asked whether a man who did wudu for prayerand then put on his leather socks, and then urinated and took them off and put them back on again, should begin wudu afresh. Malik replied, "He should take off his socks and wash his feet. Only someone who puts on leather socks when his feet are (already) ritually purified by wudu can wipe over them. Someone who puts on leather socks when his feet are not ritually purified by wudu, should not wipe over them." Yahya said that Malik was asked about a man who did wudu with his leather socks on and forgot to wipe over them until the water was dry and he had prayed, and he said, "He should wipe over his socks and repeat the prayer but not repeat wudu." Malik was asked about a man who washed his feet and put on his leather socks and then started doing wudu, and he said, "He should take off his socks and do wudu and wash his feet}}
\hadithdefcmd{malik}{75}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، أَنَّهُ رَأَى أَبَاهُ يَمْسَحُ عَلَى الْخُفَّيْنِ قَالَ وَكَانَ لاَ يَزِيدُ إِذَا مَسَحَ عَلَى الْخُفَّيْنِ عَلَى أَنْ يَمْسَحَ ظُهُورَهُمَا وَلاَ يَمْسَحُ بُطُونَهُمَا ‏.‏\hadithno{75}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa that he saw his father wiping over his leather socks. He said, "When he wiped over his socks he would never do more than wipe the tops and he would not wipe the bottoms}}
\hadithdefcmd{malik}{76}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ سَأَلَ ابْنَ شِهَابٍ عَنِ الْمَسْحِ، عَلَى الْخُفَّيْنِ كَيْفَ هُوَ فَأَدْخَلَ ابْنُ شِهَابٍ إِحْدَى يَدَيْهِ تَحْتَ الْخُفِّ وَالأُخْرَى فَوْقَهُ ثُمَّ أَمَرَّهُمَا ‏.‏ قَالَ يَحْيَى قَالَ مَالِكٌ وَقَوْلُ ابْنِ شِهَابٍ أَحَبُّ مَا سَمِعْتُ إِلَىَّ فِي ذَلِكَ ‏.‏\hadithno{76}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me that Malik had asked Ibn Shihab how to wipe over leather socks. Ibn Shihab had put one hand under the sock and his other hand above the sock and then passed them over it. Yahya said that Malik said, "Out of all that I have heard about the matter I like what Ibn Shihab said the most}}
\hadithdefcmd{malik}{77}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ إِذَا رَعَفَ انْصَرَفَ فَتَوَضَّأَ ثُمَّ رَجَعَ فَبَنَى وَلَمْ يَتَكَلَّمْ ‏.‏\hadithno{77}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar would leave and do wudu if he had a nose-bleed and then return and complete his prayer without saying anything}}
\hadithdefcmd{malik}{78}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ، كَانَ يَرْعُفُ فَيَخْرُجُ فَيَغْسِلُ الدَّمَ عَنْهُ ثُمَّ يَرْجِعُ فَيَبْنِي عَلَى مَا قَدْ صَلَّى ‏.‏\hadithno{78}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Abbas used to have nose-bleeds and would leave to wash off the blood. He would then return and complete his prayer}}
\hadithdefcmd{malik}{79}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ بْنِ قُسَيْطٍ اللَّيْثِيِّ، أَنَّهُ رَأَى سَعِيدَ بْنَ الْمُسَيَّبِ رَعَفَ وَهُوَ يُصَلِّي فَأَتَى حُجْرَةَ أُمِّ سَلَمَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم فَأُتِيَ بِوَضُوءٍ فَتَوَضَّأَ ثُمَّ رَجَعَ فَبَنَى عَلَى مَا قَدْ صَلَّى ‏.‏\hadithno{79}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Yazid ibn Abdullah Qusayt al- Laythi that he saw Said ibn al-Musayyab having a nose-bleed while praying. He went off to the room of Umm Salama, the wife of the Prophet, may Allah bless him and grant him peace, and water was brought to him and he did wudu. He then returned and completed his prayer}}
\hadithdefcmd{malik}{80}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ حَرْمَلَةَ الأَسْلَمِيِّ، أَنَّهُ قَالَ رَأَيْتُ سَعِيدَ\hadithno{80}\hadithgrade{Salim al-Hilali: Maqtu Hasan}\hadithtrans{Yahya related to me that Abd ar-Rahman ibn Harmala al-Aslami said, "I saw Said ibn al-Musayyab with his nose bleeding and blood poured out of it so that his fingers were all red from the blood coming out of his nose, and he prayed without doing wudu}}
\hadithdefcmd{malik}{81}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْمُجَبَّرِ، أَنَّهُ رَأَى سَالِمَ بْنَ عَبْدِ اللَّهِ يَخْرُجُ مِنْ أَنْفِهِ الدَّمُ حَتَّى تَخْتَضِبَ أَصَابِعُهُ ثُمَّ يَفْتِلُهُ ثُمَّ يُصَلِّي وَلاَ يَتَوَضَّأُ ‏.‏\hadithno{81}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Abd ar Rahman ibn al-Mujabbar that he saw Salim ibn Abdullah with blood running from his nose so that his fingers were all coloured red. Then he rubbed it and prayed without doing wudu}}
\hadithdefcmd{malik}{82}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّ الْمِسْوَرَ بْنَ مَخْرَمَةَ، أَخْبَرَهُ أَنَّهُ، دَخَلَ عَلَى عُمَرَ بْنِ الْخَطَّابِ مِنَ اللَّيْلَةِ الَّتِي طُعِنَ فِيهَا فَأَيْقَظَ عُمَرَ لِصَلاَةِ الصُّبْحِ فَقَالَ عُمَرُ نَعَمْ وَلاَ حَظَّ فِي الإِسْلاَمِ لِمَنْ تَرَكَ الصَّلاَةَ ‏.‏ فَصَلَّى عُمَرُ وَجُرْحُهُ يَثْعَبُ دَمًا ‏.‏\hadithno{82}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Hisham ibn Urwa from his father that al- Miswar ibn Makhrama told him that he had visited Umar ibn al Khattab on the night he was stabbed and had woken him up for the subh prayer and Umar had said, ''Yes. Whoever stops doing the prayer will get nothing from Islam," and he did the prayer with blood pouring from his wound}}
\hadithdefcmd{malik}{83}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّ سَعِيدَ بْنَ الْمُسَيَّبِ، قَالَ مَا تَرَوْنَ فِيمَنْ غَلَبَهُ الدَّمُ مِنْ رُعَافٍ فَلَمْ يَنْقَطِعْ عَنْهُ قَالَ مَالِكٌ قَالَ يَحْيَى بْنُ سَعِيدٍ ثُمَّ قَالَ سَعِيدُ بْنُ الْمُسَيَّبِ أَرَى أَنْ يُومِئَ بِرَأْسِهِ إِيمَاءً ‏.‏ قَالَ يَحْيَى قَالَ مَالِكٌ وَذَلِكَ أَحَبُّ مَا سَمِعْتُ إِلَىَّ فِي ذَلِكَ ‏.‏\hadithno{83}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that Said ibn al-Musayyab was asked, "What do you say about someone who is afflicted by a nose-bleed which does not stop? "Malik said that Yahya ibn Said said that Said ibn al Musayyab said, "I say that he should signal with his head." (i.e. instead of doing sajda or ruku.) Yahya said that Malik said, "That is what I like most out of what I have heard about the matter}}
\hadithdefcmd{malik}{84}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ أَبِي النَّضْرِ، مَوْلَى عُمَرَ بْنِ عُبَيْدِ اللَّهِ عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنِ الْمِقْدَادِ بْنِ الأَسْوَدِ، أَنَّ عَلِيَّ بْنَ أَبِي طَالِبٍ، أَمَرَهُ أَنْ يَسْأَلَ، لَهُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الرَّجُلِ إِذَا دَنَا مِنْ أَهْلِهِ فَخَرَجَ مِنْهُ الْمَذْىُ مَاذَا عَلَيْهِ قَالَ عَلِيٌّ فَإِنَّ عِنْدِي ابْنَةَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَنَا أَسْتَحِي أَنْ أَسْأَلَهُ ‏.‏ قَالَ الْمِقْدَادُ فَسَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ فَقَالَ ‏ "‏ إِذَا وَجَدَ ذَلِكَ أَحَدُكُمْ فَلْيَنْضَحْ فَرْجَهُ بِالْمَاءِ وَلْيَتَوَضَّأْ وُضُوءَهُ لِلصَّلاَةِ ‏"‏ ‏.‏\hadithno{84}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Abu'n Nadr, the mawla of Abdullah ibn Ubaydullah, from Sulayman ibn Yasar from alMiqdad ibn al- Aswad that Ali ibn Abi Talib told him to ask the Messenger of Allah, may Allah bless him and grant him peace, what a man should do, who, when close to his wife, had a flow of prostatic fluid. Ali explained that the daughter of the Messenger of Allah, may Allah bless him and grant him peace, was living with him then and he was too shy to ask for himself. Al-Miqdad said, "I asked the Messenger of Allah, may Allah bless him and grant him peace, about it, and he said, 'When you find that, wash your genitals with water and do wudu as for prayer}}
\hadithdefcmd{malik}{85}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، قَالَ إِنِّي لأَجِدُهُ يَنْحَدِرُ مِنِّي مِثْلَ الْخُرَيْزَةِ فَإِذَا وَجَدَ ذَلِكَ أَحَدُكُمْ فَلْيَغْسِلْ ذَكَرَهُ وَلْيَتَوَضَّأْ وُضُوءَهُ لِلصَّلاَةِ يَعْنِي الْمَذْىَ ‏.‏\hadithno{85}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Zayd ibn Aslam from his father that Umar ibn al-Khattab said, "I find it dropping from me like small beads. When you find that, wash your penis and do wudu as for prayer}}
\hadithdefcmd{malik}{86}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ جُنْدَبٍ، مَوْلَى عَبْدِ اللَّهِ بْنِ عَيَّاشٍ أَنَّهُ قَالَ سَأَلْتُ عَبْدَ اللَّهِ بْنَ عُمَرَ عَنِ الْمَذْىِ، فَقَالَ إِذَا وَجَدْتَهُ فَاغْسِلْ فَرْجَكَ وَتَوَضَّأْ وُضُوءَكَ لِلصَّلاَةِ ‏.‏\hadithno{86}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam from his father that Jundub, the mawla of Abdullah ibn Ayyash, said, "I asked Abdullah ibn Umar about prostatic fluid and he said, 'When you find it, wash your genitals and do wudu as for prayer}}
\hadithdefcmd{malik}{87}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّهُ سَمِعَهُ وَرَجُلٌ، يَسْأَلُهُ فَقَالَ إِنِّي لأَجِدُ الْبَلَلَ وَأَنَا أُصَلِّي، أَفَأَنْصَرِفُ فَقَالَ لَهُ سَعِيدٌ لَوْ سَالَ عَلَى فَخِذِي مَا انْصَرَفْتُ حَتَّى أَقْضِيَ صَلاَتِي ‏.‏\hadithno{87}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that he was listening to Said ibn al-Musayyab and a man questioned him saying, "I discover a liquid when I am praying. Should I leave?" Said ibn al-Musayyab said to him, "Even if it were to flow on my leg I would not leave until I had finished the prayer}}
\hadithdefcmd{malik}{88}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ الصَّلْتِ بْنِ زُيَيْدٍ، أَنَّهُ قَالَ سَأَلْتُ سُلَيْمَانَ بْنَ يَسَارٍ عَنِ الْبَلَلِ، أَجِدُهُ فَقَالَ انْضَحْ مَا تَحْتَ ثَوْبِكَ بِالْمَاءِ وَالْهَ عَنْهُ ‏.‏\hadithno{88}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that as-Salt ibn Zuyayd said, "I asked Sulayman ibn Yasar about a liquid I discovered. He said, 'Wash what is under your garments with water and forget about it}}
\hadithdefcmd{malik}{89}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ، أَنَّهُ سَمِعَ عُرْوَةَ بْنَ الزُّبَيْرِ، يَقُولُ دَخَلْتُ عَلَى مَرْوَانَ بْنِ الْحَكَمِ فَتَذَاكَرْنَا مَا يَكُونُ مِنْهُ الْوُضُوءُ فَقَالَ مَرْوَانُ وَمِنْ مَسِّ الذَّكَرِ الْوُضُوءُ ‏.‏ فَقَالَ عُرْوَةُ مَا عَلِمْتُ هَذَا ‏.‏ فَقَالَ مَرْوَانُ بْنُ الْحَكَمِ أَخْبَرَتْنِي بُسْرَةُ بِنْتُ صَفْوَانَ أَنَّهَا سَمِعَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا مَسَّ أَحَدُكُمْ ذَكَرَهُ فَلْيَتَوَضَّأْ ‏"‏ ‏.‏\hadithno{89}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik that Abdullah ibn Abi Bakr ibn Muhammad ibn Amr ibn Hazim heard Urwa ibn az-Zubayr saying, "I went to see Marwan ibn al-Hakam and we talked about what you had to do wudu for, and Marwan said, 'You have to do wudu if you touch your penis.' Urwa said, 'I didn't know that.' Marwan ibn al-Hakam said that Busra bint Safwan had told him that she heard the Messenger of Allah, may Allah bless him and grant him peace, say, 'If any of you touches his penis he should do wudu}}
\hadithdefcmd{malik}{90}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ إِسْمَاعِيلَ بْنِ مُحَمَّدِ بْنِ سَعْدِ بْنِ أَبِي وَقَّاصٍ، عَنْ مُصْعَبِ بْنِ سَعْدِ بْنِ أَبِي وَقَّاصٍ، أَنَّهُ قَالَ كُنْتُ أُمْسِكُ الْمُصْحَفَ عَلَى سَعْدِ بْنِ أَبِي وَقَّاصٍ فَاحْتَكَكْتُ فَقَالَ سَعْدٌ لَعَلَّكَ مَسِسْتَ ذَكَرَكَ قَالَ فَقُلْتُ نَعَمْ ‏.‏ فَقَالَ قُمْ فَتَوَضَّأْ فَقُمْتُ فَتَوَضَّأْتُ ثُمَّ رَجَعْتُ ‏.‏\hadithno{90}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ismail ibn Muhammad ibn Sad ibn Abi Waqqas that Musab ibn Sad ibn Abi Waqqas said, "I was holding the Book for Sad ibn Abi Waqqas and I rubbed myself. Sad said, 'Did you touch your penis?' I replied, 'Yes,' and he said, 'Get up and do wudu.' So I got up and did wudu and then returned}}
\hadithdefcmd{malik}{91}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَقُولُ إِذَا مَسَّ أَحَدُكُمْ ذَكَرَهُ فَقَدْ وَجَبَ عَلَيْهِ الْوُضُوءُ ‏.‏\hadithno{91}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to say, "If you touch your penis you have to do wudu}}
\hadithdefcmd{malik}{92}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّهُ كَانَ يَقُولُ مَنْ مَسَّ ذَكَرَهُ فَقَدْ وَجَبَ عَلَيْهِ الْوُضُوءُ ‏.‏\hadithno{92}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa that his father used to say, "If any of you touches his penis he has to do wudu}}
\hadithdefcmd{malik}{93}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، أَنَّهُ قَالَ رَأَيْتُ أَبِي عَبْدَ اللَّهِ بْنَ عُمَرَ يَغْتَسِلُ ثُمَّ يَتَوَضَّأُ فَقُلْتُ لَهُ يَا أَبَتِ أَمَا يَجْزِيكَ الْغُسْلُ مِنَ الْوُضُوءِ قَالَ بَلَى وَلَكِنِّي أَحْيَانًا أَمَسُّ ذَكَرِي فَأَتَوَضَّأُ ‏.‏\hadithno{93}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related from Malik from Ibn Shihab that Salim ibn Abdullah said, "I saw my father Abdullah ibn Umar, do ghusl and then do wudu. I said to him, 'Father, isn't ghusl enough for you?' He said, 'Of course, but sometimes I touch my penis, so I do wudu}}
\hadithdefcmd{malik}{94}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، أَنَّهُ قَالَ كُنْتُ مَعَ عَبْدِ اللَّهِ بْنِ عُمَرَ فِي سَفَرٍ فَرَأَيْتُهُ بَعْدَ أَنْ طَلَعَتِ الشَّمْسُ تَوَضَّأَ ثُمَّ صَلَّى قَالَ فَقُلْتُ لَهُ إِنَّ هَذِهِ لَصَلاَةٌ مَا كُنْتَ تُصَلِّيهَا ‏.‏ قَالَ إِنِّي بَعْدَ أَنْ تَوَضَّأْتُ لِصَلاَةِ الصُّبْحِ مَسِسْتُ فَرْجِي ثُمَّ نَسِيتُ أَنْ أَتَوَضَّأَ فَتَوَضَّأْتُ وَعُدْتُ لِصَلاَتِي ‏.‏\hadithno{94}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Salim ibn 'Abdullah said, "I was with Abdullah ibn Umar on a journey and after the sun had risen I saw him do wudu and then pray. So I said to him, 'This isn't a prayer that you normally do. 'He said, 'After I had done wudu for the subh prayer, I touched my genitals. Then I forgot to do wudu. So I did wudu again and repeated my prayer}}
\hadithdefcmd{malik}{95}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ كَانَ يَقُولُ قُبْلَةُ الرَّجُلِ امْرَأَتَهُ وَجَسُّهَا بِيَدِهِ مِنَ الْمُلاَمَسَةِ فَمَنْ قَبَّلَ امْرَأَتَهُ أَوْ جَسَّهَا بِيَدِهِ فَعَلَيْهِ الْوُضُوءُ ‏.‏\hadithno{95}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Salim ibn Abdullah that his father Abdullah ibn Umar used to say, "A man's kissing his wife and fondling her with his hands are part of intercourse. Someone who kisses his wife or fondles her with his hand must do wudu}}
\hadithdefcmd{malik}{96}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عَبْدَ اللَّهِ بْنَ مَسْعُودٍ، كَانَ يَقُولُ مِنْ قُبْلَةِ الرَّجُلِ امْرَأَتَهُ الْوُضُوءُ ‏.‏\hadithno{96}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that he had heard that Abdullah ibn Masud used to say, "Wudu is necessary if a man kisses his wife}}
\hadithdefcmd{malik}{97}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، أَنَّهُ كَانَ يَقُولُ مِنْ قُبْلَةِ الرَّجُلِ امْرَأَتَهُ الْوُضُوءُ ‏.‏ قَالَ ‏\{‏ ابْنُ ‏\}‏ نَافِعٍ قَالَ مَالِكٌ وَذَلِكَ أَحَبُّ مَا سَمِعْتُ إِلَىَّ ‏.‏\hadithno{97}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that Ibn Shihab used to say, "Wudu is necessary if a man kisses his wife." Nafi said that Malik said, "That is what I like most out of what I have heard}}
\hadithdefcmd{malik}{98}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا اغْتَسَلَ مِنَ الْجَنَابَةِ بَدَأَ بِغَسْلِ يَدَيْهِ ثُمَّ تَوَضَّأَ كَمَا يَتَوَضَّأُ لِلصَّلاَةِ ثُمَّ يُدْخِلُ أَصَابِعَهُ فِي الْمَاءِ فَيُخَلِّلُ بِهَا أُصُولَ شَعْرِهِ ثُمَّ يَصُبُّ عَلَى رَأْسِهِ ثَلاَثَ غَرَفَاتٍ بِيَدَيْهِ ثُمَّ يُفِيضُ الْمَاءَ عَلَى جِلْدِهِ كُلِّهِ ‏.‏\hadithno{98}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father from A'isha, umm al-muminin, that whenever the Messenger of Allah, may Allah bless him and grant him peace, did ghusl for major ritual impurity, he would begin by washing his hands, and then do wudu as for prayer. He would then put his fingers in the water and rub the roots of his hair with them. Then he would pour as much water as two hands can hold on to his head three times, and over the entire surface of his skin}}
\hadithdefcmd{malik}{99}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَغْتَسِلُ مِنْ إِنَاءٍ - هُوَ الْفَرَقُ - مِنَ الْجَنَابَةِ ‏.‏\hadithno{99}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Urwa ibn az- Zubayr from A'isha, umm al-muminin, that the Messenger of Allah, may Allah bless him and grant him peace, used to do ghusl for major ritual impurity from a vessel which contained a faraq}}
\hadithdefcmd{malik}{100}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ إِذَا اغْتَسَلَ مِنَ الْجَنَابَةِ بَدَأَ فَأَفْرَغَ عَلَى يَدِهِ الْيُمْنَى فَغَسَلَهَا ثُمَّ غَسَلَ فَرْجَهُ ثُمَّ مَضْمَضَ وَاسْتَنْثَرَ ثُمَّ غَسَلَ وَجْهَهُ وَنَضَحَ فِي عَيْنَيْهِ ثُمَّ غَسَلَ يَدَهُ الْيُمْنَى ثُمَّ الْيُسْرَى ثُمَّ غَسَلَ رَأْسَهُ ثُمَّ اغْتَسَلَ وَأَفَاضَ عَلَيْهِ الْمَاءَ ‏.‏\hadithno{100}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that when Abdullah ibn Umar used to do ghusl for major ritual impurity he would begin by pouring water on his right hand and washing it. Then, in order, he would wash his genitals, rinse his mouth, snuff water in and out of his nose, wash his face and splash his eyes with water. Then he would wash his right arm and then his left, and after that he would wash his head. He would finish by having a complete wash and pouring water all over himself}}
\hadithdefcmd{malik}{101}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عَائِشَةَ، سُئِلَتْ عَنْ غُسْلِ الْمَرْأَةِ، مِنَ الْجَنَابَةِ فَقَالَتْ لِتَحْفِنْ عَلَى رَأْسِهَا ثَلاَثَ حَفَنَاتٍ مِنَ الْمَاءِ وَلْتَضْغَثْ رَأْسَهَا بِيَدَيْهَا ‏.‏\hadithno{101}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that he had heard that A'isha was asked about how a woman should do ghusl for major ritual impurity. She said, "She should scoop water over her head with both hands three times and rub the roots of her hair with her hands}}
\hadithdefcmd{malik}{102}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، وَعُثْمَانَ بْنَ عَفَّانَ، وَعَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم كَانُوا يَقُولُونَ إِذَا مَسَّ الْخِتَانُ الْخِتَانَ فَقَدْ وَجَبَ الْغُسْلُ ‏.‏\hadithno{102}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Said ibn al- Musayyab that Umar ibn al-Khattab and Uthman ibn Affan and A'isha, the wife of the Prophet, may Allah bless him and grant him peace, used to say, "When the circumcised part touches the circumcised part, ghusl is obligatory}}
\hadithdefcmd{malik}{103}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي النَّضْرِ، مَوْلَى عُمَرَ بْنِ عُبَيْدِ اللَّهِ عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، أَنَّهُ قَالَ سَأَلْتُ عَائِشَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم مَا يُوجِبُ الْغُسْلَ فَقَالَتْ هَلْ تَدْرِي مَا مَثَلُكَ يَا أَبَا سَلَمَةَ مَثَلُ الْفَرُّوجِ يَسْمَعُ الدِّيَكَةَ تَصْرُخُ فَيَصْرُخُ مَعَهَا إِذَا جَاوَزَ الْخِتَانُ الْخِتَانَ فَقَدْ وَجَبَ الْغُسْلُ ‏.‏\hadithno{103}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Abu'n Nadr, the mawla of Umar ibn Abdullah that Abu Salamaibn Abdar-Rahman ibn Awf related that he had asked A'isha, the wife of the Prophet, may Allah bless him and grant him peace, what made ghusl obligatory. She said, "Do you know what you are like, Abu Salama? You are like a chick when it hears the cocks crowing and so crows with them. When the circumcised part passes the circumcised part, ghusl is obligatory}}
\hadithdefcmd{malik}{104}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّ أَبَا مُوسَى الأَشْعَرِيَّ، أَتَى عَائِشَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم فَقَالَ لَهَا لَقَدْ شَقَّ عَلَىَّ اخْتِلاَفُ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم فِي أَمْرٍ إِنِّي لأُعْظِمُ أَنْ أَسْتَقْبِلَكِ بِهِ ‏.‏ فَقَالَتْ مَا هُوَ مَا كُنْتَ سَائِلاً عَنْهُ أُمَّكَ فَسَلْنِي عَنْهُ ‏.‏ فَقَالَ الرَّجُلُ يُصِيبُ أَهْلَهُ ثُمَّ يُكْسِلُ وَلاَ يُنْزِلُ فَقَالَتْ إِذَا جَاوَزَ الْخِتَانُ الْخِتَانَ فَقَدْ وَجَبَ الْغُسْلُ ‏.‏ فَقَالَ أَبُو مُوسَى الأَشْعَرِيُّ لاَ أَسْأَلُ عَنْ هَذَا أَحَدًا بَعْدَكِ أَبَدًا ‏.‏\hadithno{104}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from Said ibn al-Musayyab that Abu Musa al-Ashari came to A'isha, the wife of the Prophet, may Allah bless him and grant him peace, and said to her, "The disagreement of the companions in a matter which I hate to bring before you has distressed me." She said, "What is that? You did not ask your mother about it, so ask me." He said, "A man penetrates his wife, but becomes listless and does not ejaculate. "She said, "When the circumcised part passes the circumcised part ghusl is obligatory." Abu Musa added, "I shall never ask anyone about this after you}}
\hadithdefcmd{malik}{105}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَبْدِ اللَّهِ بْنِ كَعْبٍ، مَوْلَى عُثْمَانَ بْنِ عَفَّانَ أَنَّ مَحْمُودَ بْنَ لَبِيدٍ الأَنْصَارِيَّ، سَأَلَ زَيْدَ بْنَ ثَابِتٍ عَنِ الرَّجُلِ، يُصِيبُ أَهْلَهُ ثُمَّ يُكْسِلُ وَلاَ يُنْزِلُ فَقَالَ زَيْدٌ يَغْتَسِلُ ‏.‏ فَقَالَ لَهُ مَحْمُودٌ إِنَّ أُبَىَّ بْنَ كَعْبٍ كَانَ لاَ يَرَى الْغُسْلَ ‏.‏ فَقَالَ لَهُ زَيْدُ بْنُ ثَابِتٍ إِنَّ أُبَىَّ بْنَ كَعْبٍ نَزَعَ عَنْ ذَلِكَ قَبْلَ أَنْ يَمُوتَ ‏.‏\hadithno{105}\hadithgrade{Salim al-Hilali: Mauquf Hasan}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from Abdullah ibn Kab, the mawla of Uthman ibn Affan that Mahmud ibn Labid al-Ansari asked Zayd ibn Thabit about a man who penetrated his wife but became listless and did not ejaculate. Zayd ibn Thabit said, "He does ghusl." Mahmud said to him, "Ubayy ibn Kab used not to think that ghusl was necessary," but Zayd ibn Thabit said, "Ubayy ibn Kab drew away from that before he died}}
\hadithdefcmd{malik}{106}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَقُولُ إِذَا جَاوَزَ الْخِتَانُ الْخِتَانَ فَقَدْ وَجَبَ الْغُسْلُ ‏.‏\hadithno{106}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to say, "When the circumcised part passes the circumcised part, ghusl is obligatory}}
\hadithdefcmd{malik}{107}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ قَالَ ذَكَرَ عُمَرُ بْنُ الْخَطَّابِ لِرَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ يُصِيبُهُ جَنَابَةٌ مِنَ اللَّيْلِ فَقَالَ لَهُ رَسُولُ اللَّهِ ‏ "‏ تَوَضَّأْ وَاغْسِلْ ذَكَرَكَ ثُمَّ نَمْ ‏"‏ ‏.‏\hadithno{107}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Dinar that Abdullah ibn Umar related that Umar ibn al-Khattab mentioned to the Messenger of Allah, may Allah bless him and grant him peace, that he would sometimes become junub in the night. The Messenger of Allah, may Allah bless him and grant him peace, said to him, "Do wudu and wash your penis, and then sleep}}
\hadithdefcmd{malik}{108}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا كَانَتْ تَقُولُ إِذَا أَصَابَ أَحَدُكُمُ الْمَرْأَةَ ثُمَّ أَرَادَ أَنْ يَنَامَ قَبْلَ أَنْ يَغْتَسِلَ فَلاَ يَنَمْ حَتَّى يَتَوَضَّأَ وُضُوءَهُ لِلصَّلاَةِ ‏.‏\hadithno{108}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, used to say, "If you have intercourse with your wife and then wish to go to sleep before doing ghusl, do not sleep until you have done wudu as for prayer}}
\hadithdefcmd{malik}{109}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ إِذَا أَرَادَ أَنْ يَنَامَ، أَوْ يَطْعَمَ وَهُوَ جُنُبٌ غَسَلَ وَجْهَهُ وَيَدَيْهِ إِلَى الْمِرْفَقَيْنِ وَمَسَحَ بِرَأْسِهِ ثُمَّ طَعِمَ أَوْ نَامَ ‏.‏\hadithno{109}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar, if he wished to sleep or eat while junub, would wash his face, and his arms to the elbows, and wipe his head. Then he would eat or sleep. 2.20 The Repetition of the Prayer by a Person in a State of Major Ritual Impurity, his Doing Ghusl, when He has Prayed without Remembering it, and his Washing his Garments}}
\hadithdefcmd{malik}{110}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي حَكِيمٍ، أَنَّ عَطَاءَ بْنَ يَسَارٍ، أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَبَّرَ فِي صَلاَةٍ مِنَ الصَّلَوَاتِ ثُمَّ أَشَارَ إِلَيْهِمْ بِيَدِهِ أَنِ امْكُثُوا فَذَهَبَ ثُمَّ رَجَعَ وَعَلَى جِلْدِهِ أَثَرُ الْمَاءِ ‏.‏\hadithno{110}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Ismail ibn Abi Hakim that Ata ibn Yasar told him that the Messenger of Allah, may Allah bless him and grant him peace, said the takbir in one of the prayers and then indicated to them with his hand to stay in place. He left and then returned with traces of water on his skin}}
\hadithdefcmd{malik}{111}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ زُيَيْدِ بْنِ الصَّلْتِ، أَنَّهُ قَالَ خَرَجْتُ مَعَ عُمَرَ بْنِ الْخَطَّابِ إِلَى الْجُرُفِ فَنَظَرَ فَإِذَا هُوَ قَدِ احْتَلَمَ وَصَلَّى وَلَمْ يَغْتَسِلْ فَقَالَ وَاللَّهِ مَا أَرَانِي إِلاَّ احْتَلَمْتُ وَمَا شَعَرْتُ وَصَلَّيْتُ وَمَا اغْتَسَلْتُ قَالَ فَاغْتَسَلَ وَغَسَلَ مَا رَأَى فِي ثَوْبِهِ وَنَضَحَ مَا لَمْ يَرَ وَأَذَّنَ أَوْ أَقَامَ ثُمَّ صَلَّى بَعْدَ ارْتِفَاعِ الضُّحَى مُتَمَكِّنًا ‏.‏\hadithno{111}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa that Zuyayd ibn as-Salt said, "I went with Umar ibn al-Khattab to Juruf and he looked down and noticed that he had had a wet dream and had prayed without doing ghusl. He exclaimed, 'By Allah I realise that I have had a wet dream and did not know it and have not done ghusl.' So he did ghusl and washed off whatever he saw on his garment, and sprinkled with water whatever he did not see.Then he gave the adhan or the iqama and prayed in the midmorning}}
\hadithdefcmd{malik}{112}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي حَكِيمٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، غَدَا إِلَى أَرْضِهِ بِالْجُرُفِ فَوَجَدَ فِي ثَوْبِهِ احْتِلاَمًا فَقَالَ لَقَدِ ابْتُلِيتُ بِالاِحْتِلاَمِ مُنْذُ وُلِّيتُ أَمْرَ النَّاسِ ‏.‏ فَاغْتَسَلَ وَغَسَلَ مَا رَأَى فِي ثَوْبِهِ مِنَ الاِحْتِلاَمِ ثُمَّ صَلَّى بَعْدَ أَنْ طَلَعَتِ الشَّمْسُ ‏.‏\hadithno{112}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Ismail ibn Abi Hakim from Sulayman ibn Yasar that Umar ibn al-Khattab went out early in the morning to his land in al-Juruf and found semen on his garment. He said, "I have been tried with wet dreams since I have been entrusted with governing the people." He did ghusl and washed his garment of what he saw of the semen, and then prayed after the sun had risen}}
\hadithdefcmd{malik}{113}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، صَلَّى بِالنَّاسِ الصُّبْحَ ثُمَّ غَدَا إِلَى أَرْضِهِ بِالْجُرُفِ فَوَجَدَ فِي ثَوْبِهِ احْتِلاَمًا فَقَالَ إِنَّا لَمَّا أَصَبْنَا الْوَدَكَ لاَنَتِ الْعُرُوقُ ‏.‏ فَاغْتَسَلَ وَغَسَلَ الاِحْتِلاَمَ مِنْ ثَوْبِهِ وَعَادَ لِصَلاَتِهِ ‏.‏\hadithno{113}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from Sulayman ibn Yasar that Umar ibn al-Khattab led the people in the subh prayer and then went out to his land in Juruf and found semen on his clothes. He said, "Since we have been eating rich meat our veins have become fulsome." He did ghusl, washed the semen from his clothing, and did his prayer again}}
\hadithdefcmd{malik}{114}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ يَحْيَى بْنِ عَبْدِ الرَّحْمَنِ بْنِ حَاطِبٍ، أَنَّهُ اعْتَمَرَ مَعَ عُمَرَ بْنِ الْخَطَّابِ فِي رَكْبٍ فِيهِمْ عَمْرُو بْنُ الْعَاصِ وَأَنَّ عُمَرَ بْنَ الْخَطَّابِ عَرَّسَ بِبَعْضِ الطَّرِيقِ قَرِيبًا مِنْ بَعْضِ الْمِيَاهِ فَاحْتَلَمَ عُمَرُ وَقَدْ كَادَ أَنْ يُصْبِحَ فَلَمْ يَجِدْ مَعَ الرَّكْبِ مَاءً فَرَكِبَ حَتَّى جَاءَ الْمَاءَ فَجَعَلَ يَغْسِلُ مَا رَأَى مِنْ ذَلِكَ الاِحْتِلاَمِ حَتَّى أَسْفَرَ فَقَالَ لَهُ عَمْرُو بْنُ الْعَاصِ أَصْبَحْتَ وَمَعَنَا ثِيَابٌ فَدَعْ ثَوْبَكَ يُغْسَلُ ‏.‏ فَقَالَ عُمَرُ بْنُ الْخَطَّابِ وَاعَجَبًا لَكَ يَا عَمْرُو بْنَ الْعَاصِ لَئِنْ كُنْتَ تَجِدُ ثِيَابًا أَفَكُلُّ النَّاسِ يَجِدُ ثِيَابًا وَاللَّهِ لَوْ فَعَلْتُهَا لَكَانَتْ سُنَّةً بَلْ أَغْسِلُ مَا رَأَيْتُ وَأَنْضِحُ مَا لَمْ أَرَ ‏.‏ قَالَ مَالِكٌ فِي رَجُلٍ وَجَدَ فِي ثَوْبِهِ أَثَرَ احْتِلاَمٍ وَلاَ يَدْرِي مَتَى كَانَ وَلاَ يَذْكُرُ شَيْئًا رَأَى فِي مَنَامِهِ قَالَ لِيَغْتَسِلْ مِنْ أَحْدَثِ نَوْمٍ نَامَهُ فَإِنْ كَانَ صَلَّى بَعْدَ ذَلِكَ النَّوْمِ فَلْيُعِدْ مَا كَانَ صَلَّى بَعْدَ ذَلِكَ النَّوْمِ مِنْ أَجْلِ أَنَّ الرَّجُلَ رُبَّمَا احْتَلَمَ وَلاَ يَرَى شَيْئًا وَيَرَى وَلاَ يَحْتَلِمُ فَإِذَا وَجَدَ فِي ثَوْبِهِ مَاءً فَعَلَيْهِ الْغُسْلُ وَذَلِكَ أَنَّ عُمَرَ أَعَادَ مَا كَانَ صَلَّى لآخِرِ نَوْمٍ نَامَهُ وَلَمْ يُعِدْ مَا كَانَ قَبْلَهُ ‏.‏\hadithno{114}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father fromYahyaibn Abd ar-Rahman ibn Ha ib that he had set off for Mumra with Umar ibn al-Khattab in a party of riders, among whom was Amr ibn al-As. Umar ibn al-Khattab dismounted for a rest late at night on a certain road near a certain oasis. Umar had a wet dream when it was almost dawn and there was no water among the riding party. He rode until he came to some water and then he began to wash off what he saw of the semen until it had gone. Amr ibn al-As said to him, "It is morning and there are clothes with us, so allow your garment to be washed. ''Umar ibn al-Khattab said to him, "I am surprised at you, Amr ibn al-As! Even if you could find clothes, would everybody be able to find them? By Allah, if I were to do it, it would become a sunna. No, I wash what I see, and I sprinkle with water what I do not see." Malik spoke about a man who found traces of a wet dream on his clothes and did not know when it had occurred and did not remember anything he had seen in his sleep. He said, "Let the intention of his ghusl be from the time when he last slept, and if he has prayed since that last sleep he should repeat it. This is because often a man has a wet dream and sees nothing, and often he sees something but does not have an emission. But, if he finds liquid on his garment he must do ghusl. This is because Umar repeated what he had prayed after the time he had last slept and not what was before it}}
\hadithdefcmd{malik}{115}{حَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، أَنَّ أُمَّ سُلَيْمٍ، قَالَتْ لِرَسُولِ اللَّهِ صلى الله عليه وسلم الْمَرْأَةُ تَرَى فِي الْمَنَامِ مِثْلَ مَا يَرَى الرَّجُلُ أَتَغْتَسِلُ فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ نَعَمْ فَلْتَغْتَسِلْ ‏"‏ ‏.‏ فَقَالَتْ لَهَا عَائِشَةُ أُفٍّ لَكِ وَهَلْ تَرَى ذَلِكَ الْمَرْأَةُ فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ تَرِبَتْ يَمِينُكِ وَمِنْ أَيْنَ يَكُونُ الشَّبَهُ ‏"‏ ‏.‏\hadithno{115}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Urwa ibn az- Zubayr that Umm Sulayman said to the Messenger of Allah, may Allah bless him and grant him peace, "Should a woman do ghusl when she experiences the same as a man in her sleep?" The Messenger of Al lah said to her, "Yes, she should do ghusl. "A'isha said to her, "Shame on you! Does a woman see that?" (i.e. a liquid.) The Messenger of Allah, may Allah bless him and grant him peace, said to her, "May your right hand be full of dust. From where does family resemblance come?}}
\hadithdefcmd{malik}{116}{حَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ زَيْنَبَ بِنْتِ أَبِي سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ جَاءَتْ أُمُّ سُلَيْمٍ امْرَأَةُ أَبِي طَلْحَةَ الأَنْصَارِيِّ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ اللَّهَ لاَ يَسْتَحْيِي مِنَ الْحَقِّ هَلْ عَلَى الْمَرْأَةِ مِنْ غُسْلٍ إِذَا هِيَ احْتَلَمَتْ فَقَالَ ‏ "‏ نَعَمْ إِذَا رَأَتِ الْمَاءَ ‏"‏ ‏.‏\hadithno{116}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father from Zaynab bint Abi Salama that Umm Salama, the wife of the Prophet, may Allah bless him and grant him peace, said, "Umm Salama, the wife of Abu Talha al-Ansari, came to the Messenger of Allah, may Allah bless him and grant him peace, and said, 'Messenger of Allah! Allah is not ashamed of the truth-does a woman have to do ghusl if she has had an erotic dream?' He said, 'Yes, if she sees any liquid}}
\hadithdefcmd{malik}{117}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَقُولُ لاَ بَأْسَ أَنْ يُغْتَسَلَ بِفَضْلِ الْمَرْأَةِ مَا لَمْ تَكُنْ حَائِضًا أَوْ جُنُبًا ‏.‏\hadithno{117}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to say, "There is no harm in doing ghusl with water that has been used by one's wife as long as she is not menstruating or in a state of major ritual impurity (junub)}}
\hadithdefcmd{malik}{118}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَعْرَقُ فِي الثَّوْبِ وَهُوَ جُنُبٌ ثُمَّ يُصَلِّي فِيهِ ‏.‏\hadithno{118}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to sweat in a garment while he was junub and then pray with it on}}
\hadithdefcmd{malik}{119}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَغْسِلُ جَوَارِيهِ رِجْلَيْهِ وَيُعْطِينَهُ الْخُمْرَةَ وَهُنَّ حُيَّضٌ ‏.‏ وَسُئِلَ مَالِكٌ عَنْ رَجُلٍ لَهُ نِسْوَةٌ وَجَوَارِي هَلْ يَطَؤُهُنَّ جَمِيعًا قَبْلَ أَنْ يَغْتَسِلَ فَقَالَ لاَ بَأْسَ بِأَنْ يُصِيبَ الرَّجُلُ جَارِيَتَيْهِ قَبْلَ أَنْ يَغْتَسِلَ فَأَمَّا النِّسَاءُ الْحَرَائِرُ فَيُكْرَهُ أَنْ يُصِيبَ الرَّجُلُ الْمَرْأَةَ الْحُرَّةَ فِي يَوْمِ الأُخْرَى فَأَمَّا أَنَّ يُصِيبَ الْجَارِيَةَ ثُمَّ يُصِيبَ الأُخْرَى وَهُوَ جُنُبٌ فَلاَ بَأْسَ بِذَلِكَ ‏.‏ وَسُئِلَ مَالِكٌ عَنْ رَجُلٍ جُنُبٍ وُضِعَ لَهُ مَاءٌ يَغْتَسِلُ بِهِ فَسَهَا فَأَدْخَلَ أَصْبُعَهُ فِيهِ لِيَعْرِفَ حَرَّ الْمَاءِ مِنْ بَرْدِهِ ‏.‏ قَالَ مَالِكٌ إِنْ لَمْ يَكُنْ أَصَابَ أَصْبُعَهُ أَذًى فَلاَ أَرَى ذَلِكَ يُنَجِّسُ عَلَيْهِ الْمَاءَ ‏.‏\hadithno{119}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that the slave girls of Abdullah ibn Umar used to wash his feet and bring him a mat of palm leaves while they were menstruating. Malik was asked whether a man who had women and slavegirlscould have intercourse with all of them before he did ghusl. He said, "There is no harm in a man having intercourse with two of his slave girls before he does ghusl. It is disapproved of, however, to go to a freewoman on another's day. There is no harm in making love first to one slave girl and then to another when one is junub." Malik was asked about a man who was junub and water was put down for him to do ghusl with.Then he forgot and put his finger into it to find out whether it was hot or cold. Malik said, "If no filth has soiled his fingers, I do not consider that that makes the water impure}}
\hadithdefcmd{malik}{120}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، أَنَّهَا قَالَتْ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي بَعْضِ أَسْفَارِهِ حَتَّى إِذَا كُنَّا بِالْبَيْدَاءِ - أَوْ بِذَاتِ الْجَيْشِ - انْقَطَعَ عِقْدٌ لِي فَأَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى الْتِمَاسِهِ وَأَقَامَ النَّاسُ مَعَهُ وَلَيْسُوا عَلَى مَاءٍ وَلَيْسَ مَعَهُمْ مَاءٌ فَأَتَى النَّاسُ إِلَى أَبِي بَكْرٍ الصِّدِّيقِ فَقَالُوا أَلاَ تَرَى مَا صَنَعَتْ عَائِشَةُ أَقَامَتْ بِرَسُولِ اللَّهِ صلى الله عليه وسلم وَبِالنَّاسِ وَلَيْسُوا عَلَى مَاءٍ وَلَيْسَ مَعَهُمْ مَاءٌ ‏.‏ قَالَتْ عَائِشَةُ فَجَاءَ أَبُو بَكْرٍ وَرَسُولُ اللَّهِ صلى الله عليه وسلم وَاضِعٌ رَأْسَهُ عَلَى فَخِذِي قَدْ نَامَ فَقَالَ حَبَسْتِ رَسُولَ اللَّهِ صلى الله عليه وسلم وَالنَّاسَ وَلَيْسُوا عَلَى مَاءٍ وَلَيْسَ مَعَهُمْ مَاءٌ قَالَتْ عَائِشَةُ فَعَاتَبَنِي أَبُو بَكْرٍ فَقَالَ مَا شَاءَ اللَّهُ أَنْ يَقُولَ وَجَعَلَ يَطْعُنُ بِيَدِهِ فِي خَاصِرَتِي فَلاَ يَمْنَعُنِي مِنَ التَّحَرُّكِ إِلاَّ مَكَانُ رَأْسِ رَسُولِ اللَّهِ صلى الله عليه وسلم عَلَى فَخِذِي فَنَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى أَصْبَحَ عَلَى غَيْرِ مَاءٍ فَأَنْزَلَ اللَّهُ تَبَارَكَ وَتَعَالَى آيَةَ التَّيَمُّمِ فَتَيَمَّمُوا ‏.‏ فَقَالَ أُسَيْدُ بْنُ حُضَيْرٍ مَا هِيَ بِأَوَّلِ بَرَكَتِكُمْ يَا آلَ أَبِي بَكْرٍ ‏.‏ قَالَتْ فَبَعَثْنَا الْبَعِيرَ الَّذِي كُنْتُ عَلَيْهِ فَوَجَدْنَا الْعِقْدَ تَحْتَهُ ‏.‏\hadithno{120}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abd arRahman ibn al-Qasim from his father that A'isha umm al-muminin said, "We went out on a journey with the Messenger of Allah, may Allah bless him and grant him peace, and, when we came to Bayda' or Dhat al-Jaysh, a necklace of mine broke. The Messenger of Allah, may Allah bless him and grant him peace, stopped to look for it and the people stopped with him. There was no water nearby and the people were not carrying any with them, so they came to Abu Bakr as-Siddiq and said, 'Don't you see what A'isha has done? She has made the Messenger of Allah, may Allah bless him and grant him peace, and the people stop when there is no water nearby and they are not carrying any with them.' " A'isha continued, "Abu Bakr came and the Messenger of Allah, may Allah bless him and grant him peace, had fallen asleep with his head on my thigh . Abu Bakr said, 'You have made the Messenger of Allah, may Allah bless him and grant him peace, and the people stop when there is no water nearby and they are not carrying any with them ' " She continued, "Abu Bakr remonstrated with me and said whatever Allah willed him to say, and began to poke me in the waist. The only thing that stopped me from moving was that the Messenger of Allah, may Allah bless him and grant him peace, had his head on my thigh. The Messenger of Allah, may Allah bless him and grant him peace, slept until morning found him with no water. Allah, the Blessed and Exalted, sent down the ayat of tayammum and so they did tayammum. Usayd ibn Hudayr said, 'This is not the first baraka from you, O family of Abu Bakr.'" A'isha added, "We roused the camel I had been on and found the necklace under it." Malik was asked whether a man who did tayammum for one prayer should do tayammum when the time of the next prayer came or whether the first tayammum was enough. He said, "No, he does tayammum for every prayer, because he has to look for water for every prayer. If he looks for it and does not find it then he does tayammum." Malik was asked whether a man who did tayammum could lead others in prayer if they were in wudu. He said, "I prefer that someone else should lead them. However, I see no harm in it if he does lead them in prayer." Yahya said that Malik said that a man who did tayammum because he could not find any water, and then stood and said the takbir and entered into the prayer, and then someone came with some water, did not stop his prayer but completed it with tayammum and did wudu for future prayers. Yahya said that Malik said, "Whoever rises for prayer and does not find water and so does what Allah has ordered him to do of tayammum has obeyed Allah. Someone who does find water is neither purer than him nor more perfect in prayer, because both have been commanded and each does as Allah has commanded. What Allah has commanded as far as wudu is concerned is for the one who finds water, and tayammum is for the one who does not find water before he enters into the prayer." Malik said that a man who was in a state of major ritual impurity could do tayammum and read his portion of Qur'an and do voluntary prayers as long as he did not find any water. This applied only to circumstances in which it was allowable to pray with tayammum}}
\hadithdefcmd{malik}{121}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّهُ أَقْبَلَ هُوَ وَعَبْدُ اللَّهِ بْنُ عُمَرَ مِنَ الْجُرُفِ حَتَّى إِذَا كَانَا بِالْمِرْبَدِ نَزَلَ عَبْدُ اللَّهِ فَتَيَمَّمَ صَعِيدًا طَيِّبًا فَمَسَحَ وَجْهَهُ وَيَدَيْهِ إِلَى الْمِرْفَقَيْنِ ثُمَّ صَلَّى ‏.‏\hadithno{121}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar and he were approaching Juruf. When they got to Mirbad, Abdullah got down and did tayammum with some good earth. He wiped his face, and his arms to the elbows, and then prayed}}
\hadithdefcmd{malik}{122}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَتَيَمَّمُ إِلَى الْمِرْفَقَيْنِ ‏.‏ وَسُئِلَ مَالِكٌ كَيْفَ التَّيَمُّمُ وَأَيْنَ يَبْلُغُ بِهِ فَقَالَ يَضْرِبُ ضَرْبَةً لِلْوَجْهِ وَضَرْبَةً لِلْيَدَيْنِ وَيَمْسَحُهُمَا إِلَى الْمِرْفَقَيْنِ ‏.‏\hadithno{122}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to do tayammum up to his elbows. Malik was asked about how tayammum was done and what parts were covered and he said, "Strike the ground once for the face and once for the arms and wipe them to the elbows}}
\hadithdefcmd{malik}{123}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ حَرْمَلَةَ، أَنَّ رَجُلاً، سَأَلَ سَعِيدَ بْنَ الْمُسَيَّبِ عَنِ الرَّجُلِ الْجُنُبِ، يَتَيَمَّمُ ثُمَّ يُدْرِكُ الْمَاءَ فَقَالَ سَعِيدٌ إِذَا أَدْرَكَ الْمَاءَ فَعَلَيْهِ الْغُسْلُ لِمَا يُسْتَقْبَلُ ‏.‏ قَالَ مَالِكٌ فِيمَنِ احْتَلَمَ وَهُوَ فِي سَفَرٍ وَلاَ يَقْدِرُ مِنَ الْمَاءِ إِلاَّ عَلَى قَدْرِ الْوُضُوءِ وَهُوَ لاَ يَعْطَشُ حَتَّى يَأْتِيَ الْمَاءَ قَالَ يَغْسِلُ بِذَلِكَ فَرْجَهُ وَمَا أَصَابَهُ مِنْ ذَلِكَ الأَذَى ثُمَّ يَتَيَمَّمُ صَعِيدًا طَيِّبًا كَمَا أَمَرَهُ اللَّهُ ‏.‏ وَسُئِلَ مَالِكٌ عَنْ رَجُلٍ جُنُبٍ أَرَادَ أَنْ يَتَيَمَّمَ فَلَمْ يَجِدْ تُرَابًا إِلاَّ تُرَابَ سَبَخَةٍ هَلْ يَتَيَمَّمُ بِالسِّبَاخِ وَهَلْ تُكْرَهُ الصَّلاَةُ فِي السِّبَاخِ قَالَ مَالِكٌ لاَ بَأْسَ بِالصَّلاَةِ فِي السِّبَاخِ وَالتَّيَمُّمِ مِنْهَا لأَنَّ اللَّهَ تَبَارَكَ وَتَعَالَى قَالَ ‏\{‏فَتَيَمَّمُوا صَعِيدًا طَيِّبًا‏\}‏ فَكُلُّ مَا كَانَ صَعِيدًا فَهُوَ يُتَيَمَّمُ بِهِ سِبَاخًا كَانَ أَوْ غَيْرَهُ ‏.‏\hadithno{123}\hadithgrade{Salim al-Hilali: Maqtu Hasan}\hadithtrans{Yahya related to me from Malik from Abd arRahman ibn Harmala that a man asked Said ibn al-Musayyab about what a man who was junub and had done tayammum should do when he came across water. Said said, "When he comes across water he must do ghusl for what comes after." Malik said about some one who had a wet dream while he was on a journey and there was only enough water for wudu and he was not thirsty and so he did not need to use it for that, "Let him wash his genitals, and whatever the semen has fallen on, with the water and then he does tayammum with good earth as Allah has ordered him." Malik was asked whether a man who was junub and wished to do tayammum but could only find salty earth could do tayammum with that earth, and whether it was disapproved of to pray on salty earth. He said, "There is no harm in praying on salty earth or in using it to do tayammum, because Allah the Blessed and Exalted has said, '...and do tayammum with good earth.' One is purified by tayammum with everything that is earth, whether it is salty or otherwise}}
\hadithdefcmd{malik}{124}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، أَنَّ رَجُلاً، سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ مَا يَحِلُّ لِي مِنِ امْرَأَتِي وَهِيَ حَائِضٌ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لِتَشُدَّ عَلَيْهَا إِزَارَهَا ثُمَّ شَأْنَكَ بِأَعْلاَهَا ‏"‏ ‏.‏\hadithno{124}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam that a man questioned the Messenger of Allah, may Allah bless him and grant him peace, saying, "What is permitted me from my wife when she is menstruating?" The Messenger of Allah, may Allah bless him and grant him peace, said, "Let her wrap her waist-wrapper round herself tightly, and then what is above that is your concern}}
\hadithdefcmd{malik}{125}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، أَنَّ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم كَانَتْ مُضْطَجِعَةً مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي ثَوْبٍ وَاحِدٍ وَأَنَّهَا قَدْ وَثَبَتْ وَثْبَةً شَدِيدَةً فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا لَكِ لَعَلَّكِ نَفِسْتِ ‏"‏ ‏.‏ يَعْنِي الْحَيْضَةَ ‏.‏ فَقَالَتْ نَعَمْ ‏.‏ قَالَ ‏"‏ شُدِّي عَلَى نَفْسِكِ إِزَارَكِ ثُمَّ عُودِي إِلَى مَضْجَعِكِ ‏"‏ ‏.‏\hadithno{125}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Rabia ibn Abi Abd ar-Rahman that on one occasion A'isha, the wife of the Prophet, may Allah bless him and grant him peace, was sleeping with the Messenger of Allah, may Allah bless him and grant him peace, in one garment, when suddenly she jumped up sharply. The Messenger of Allah, may Allah bless him and grant him peace, said to her, "What's the matter with you? Are you losing blood?", meaning menstruating. She said, "Yes." He said, "Wrap your waist-wrapper tightly about you, and return to your sleeping- place}}
\hadithdefcmd{malik}{126}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عُبَيْدَ اللَّهِ بْنَ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَرْسَلَ إِلَى عَائِشَةَ يَسْأَلُهَا هَلْ يُبَاشِرُ الرَّجُلُ امْرَأَتَهُ وَهِيَ حَائِضٌ فَقَالَتْ لِتَشُدَّ إِزَارَهَا عَلَى أَسْفَلِهَا ثُمَّ يُبَاشِرُهَا إِنْ شَاءَ ‏.‏\hadithno{126}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Nafi that Ubaydullah ibn Abdullah ibn Umar sent a question to A'isha asking her, "May a man fondle his wife when she is menstruating?" She replied, "Let her wrap her waist-wrapper around her lower part and then he may fondle her if he wishes}}
\hadithdefcmd{malik}{127}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ سَالِمَ بْنَ عَبْدِ اللَّهِ، وَسُلَيْمَانَ بْنَ يَسَارٍ، سُئِلاَ عَنِ الْحَائِضِ، هَلْ يُصِيبُهَا زَوْجُهَا إِذَا رَأَتِ الطُّهْرَ قَبْلَ أَنْ تَغْتَسِلَ فَقَالاَ لاَ حَتَّى تَغْتَسِلَ ‏.‏\hadithno{127}\hadithgrade{Salim al-Hilali: Maqtu Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik that he had heard that Salim ibn Abdullah and Sulayman ibn Yasar were asked whether the husband of a menstruating woman could have sexual intercourse with her when she saw that she was pure but before she had had a ghusl. They said, "No, not until she has had a ghusl}}
\hadithdefcmd{malik}{128}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَلْقَمَةَ بْنِ أَبِي عَلْقَمَةَ، عَنْ أُمِّهِ، مَوْلاَةِ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ أَنَّهَا قَالَتْ كَانَ النِّسَاءُ يَبْعَثْنَ إِلَى عَائِشَةَ أُمِّ الْمُؤْمِنِينَ بِالدِّرَجَةِ فِيهَا الْكُرْسُفُ فِيهِ الصُّفْرَةُ مِنْ دَمِ الْحَيْضَةِ يَسْأَلْنَهَا عَنِ الصَّلاَةِ فَتَقُولُ لَهُنَّ لاَ تَعْجَلْنَ حَتَّى تَرَيْنَ الْقَصَّةَ الْبَيْضَاءَ ‏.‏ تُرِيدُ بِذَلِكَ الطُّهْرَ مِنَ الْحَيْضَةِ ‏.‏\hadithno{128}\hadithgrade{Salim al-Hilali: Mauquf Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from AIqama ibn Abi AIqama that his mother, the mawla of A'isha, umm al-muminin, said, "Women used to send little boxes to A'isha, umm al-muminin, with a piece of cotton cloth in each one on which was yellowness from menstrual blood, asking her about the prayer. She said to them, 'Do not be hasty until you see a white discharge." By that she meant purity from menses}}
\hadithdefcmd{malik}{129}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ عَمَّتِهِ، عَنِ ابْنَةِ زَيْدِ بْنِ ثَابِتٍ، أَنَّهُ بَلَغَهَا أَنَّ نِسَاءً، كُنَّ يَدْعُونَ بِالْمَصَابِيحِ مِنْ جَوْفِ اللَّيْلِ يَنْظُرْنَ إِلَى الطُّهْرِ فَكَانَتْ تَعِيبُ ذَلِكَ عَلَيْهِنَّ وَتَقُولُ مَا كَانَ النِّسَاءُ يَصْنَعْنَ هَذَا ‏.‏ وَسُئِلَ مَالِكٌ عَنِ الْحَائِضِ تَطْهُرُ فَلاَ تَجِدُ مَاءً هَلْ تَتَيَمَّمُ قَالَ نَعَمْ لِتَتَيَمَّمْ فَإِنَّ مِثْلَهَا مِثْلُ الْجُنُبِ إِذَا لَمْ يَجِدْ مَاءً تَيَمَّمَ ‏.‏\hadithno{129}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Abi Bakr from his paternal aunt from the daughter of Zayd ibn Thabit that she had heard that women used to ask for lamps in the middle of the night to check their purity. She would criticise them for this saying, "Women never used to do this," i.e. in the time of the companions. Malik was asked whether a woman whose period had finished could do tayammum to purify herself if she could not find waterand he said, "Yes, because she is like some one in a state of major ritual impurity, who, if he cannot find water, does tayammum}}
\hadithdefcmd{malik}{130}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ فِي الْمَرْأَةِ الْحَامِلِ تَرَى الدَّمَ أَنَّهَا تَدَعُ الصَّلاَةَ ‏.‏\hadithno{130}\hadithgrade{Salim al-Hilali: Mauquf Hasan}\hadithtrans{Yahya related to me from Malik that he had heard that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, said that a pregnant woman who noticed bleeding left off from prayer}}
\hadithdefcmd{malik}{131}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ سَأَلَ ابْنَ شِهَابٍ عَنِ الْمَرْأَةِ الْحَامِلِ، تَرَى الدَّمَ قَالَ تَكُفُّ عَنِ الصَّلاَةِ، ‏.‏ قَالَ يَحْيَى قَالَ مَالِكٌ وَذَلِكَ الأَمْرُ عِنْدَنَا ‏.‏\hadithno{131}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that he asked Ibn Shihab about a pregnant woman who noticed bleeding. Ibn Shihab replied, "She refrains from prayer." Yahya said that Malik said, "That is what is done in our community}}
\hadithdefcmd{malik}{132}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ كُنْتُ أُرَجِّلُ رَأْسَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَنَا حَائِضٌ ‏.‏\hadithno{132}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, said, "I used to comb the head of the Messenger of Allah, may Allah bless him and grant him peace, while I was menstruating}}
\hadithdefcmd{malik}{133}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ فَاطِمَةَ بِنْتِ الْمُنْذِرِ بْنِ الزُّبَيْرِ، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ الصِّدِّيقِ، أَنَّهَا قَالَتْ سَأَلَتِ امْرَأَةٌ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَتْ أَرَأَيْتَ إِحْدَانَا إِذَا أَصَابَ ثَوْبَهَا الدَّمُ مِنَ الْحَيْضَةِ كَيْفَ تَصْنَعُ فِيهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أَصَابَ ثَوْبَ إِحْدَاكُنَّ الدَّمُ مِنَ الْحَيْضَةِ فَلْتَقْرُصْهُ ثُمَّ لِتَنْضَحْهُ بِالْمَاءِ ثُمَّ لِتُصَلِّي فِيهِ ‏"‏ ‏.‏\hadithno{133}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father from Fatima bint al-Mundhir ibn az-Zubayr that Asma bint Abu Bakr as-Siddiq said, "A woman questioned the Messenger of Allah, may Allah bless him and grant him peace, saying, 'If menstrual blood gets onto our clothes how do you think we should deal with it?' The Messenger of Allah, may Allah bless him and grant him peace, said, 'If menstrual blood gets onto your clothes you should wash them, and sprinkle them with water before you pray in them}}
\hadithdefcmd{malik}{134}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ قَالَتْ فَاطِمَةُ بِنْتُ أَبِي حُبَيْشٍ يَا رَسُولَ اللَّهِ إِنِّي لاَ أَطْهُرُ أَفَأَدَعُ الصَّلاَةَ فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا ذَلِكِ عِرْقٌ وَلَيْسَتْ بِالْحَيْضَةِ فَإِذَا أَقْبَلَتِ الْحَيْضَةُ فَاتْرُكِي الصَّلاَةَ فَإِذَا ذَهَبَ قَدْرُهَا فَاغْسِلِي الدَّمَ عَنْكِ وَصَلِّي ‏"‏ ‏.‏\hadithno{134}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, said, "Fatima bint Abu Hubaysh said, 'Messenger of Allah, I never become pure - am I permitted to pray?' The Messenger of Allah, may Allah bless him and grant him peace, said, 'That is a vein, not menstruation. So when your period approaches, leave off from the prayer, and when its grip leaves, wash the blood from yourself and pray}}
\hadithdefcmd{malik}{135}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ أُمِّ سَلَمَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ امْرَأَةً كَانَتْ تُهَرَاقُ الدِّمَاءَ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَاسْتَفْتَتْ لَهَا أُمُّ سَلَمَةَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ لِتَنْظُرْ إِلَى عَدَدِ اللَّيَالِي وَالأَيَّامِ الَّتِي كَانَتْ تَحِيضُهُنَّ مِنَ الشَّهْرِ قَبْلَ أَنْ يُصِيبَهَا الَّذِي أَصَابَهَا فَلْتَتْرُكِ الصَّلاَةَ قَدْرَ ذَلِكَ مِنَ الشَّهْرِ فَإِذَا خَلَّفَتْ ذَلِكَ فَلْتَغْتَسِلْ ثُمَّ لِتَسْتَثْفِرْ بِثَوْبٍ ثُمَّ لِتُصَلِّي ‏"‏ ‏.‏\hadithno{135}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi from Sulayman ibn Yasarfrom Umm Salama, the wife of the Prophet, may Allah bless him and grant him peace, that a certain woman in the time of the Messenger of Allah, may Allah bless him and grant him peace, used to bleed profusely, so Umm Salama consulted the Messenger of Allah, may Allah bless him and grant him peace, for her, and he said, "She should calculate the number of nights and days a month that she used to menstruate before it started happening, and she should leave off from prayerfor that much of the month. When she has completed that she should do ghusl, bind her private parts with a cloth, and then pray}}
\hadithdefcmd{malik}{136}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ زَيْنَبَ بِنْتِ أَبِي سَلَمَةَ، أَنَّهَا رَأَتْ زَيْنَبَ بِنْتَ جَحْشٍ الَّتِي كَانَتْ تَحْتَ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ وَكَانَتْ تُسْتَحَاضُ فَكَانَتْ تَغْتَسِلُ وَتُصَلِّي ‏.‏\hadithno{136}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father from Zaynab bint Abu Salama that she saw Zaynab bint Jahsh, the wife of Abd ar-Rahman ibn Awf, and she used to bleed as if menstruating. She would do ghusl and pray}}
\hadithdefcmd{malik}{137}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ سُمَىٍّ، مَوْلَى أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ أَنَّ الْقَعْقَاعَ بْنَ حَكِيمٍ، وَزَيْدَ بْنَ أَسْلَمَ، أَرْسَلاَهُ إِلَى سَعِيدِ بْنِ الْمُسَيَّبِ يَسْأَلُهُ كَيْفَ تَغْتَسِلُ الْمُسْتَحَاضَةُ فَقَالَ تَغْتَسِلُ مِنْ طُهْرٍ إِلَى طُهْرٍ وَتَتَوَضَّأُ لِكُلِّ صَلاَةٍ فَإِنْ غَلَبَهَا الدَّمُ اسْتَثْفَرَتْ ‏.‏\hadithno{137}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Sumayy, the mawla of Abu Bakr ibn Abd ar-Rahman that al-Qaqa ibn Hakim and Zayd ibn Aslam sent him to Said ibn al-Musayyab to ask how a woman who was bleeding as if menstruating should do ghusl. Said said, "She does a ghusl to cover from the end of one period to the end of the next, and does wudu for every prayer, and if bleeding overtakes her she should bind her private parts}}
\hadithdefcmd{malik}{138}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّهُ قَالَ لَيْسَ عَلَى الْمُسْتَحَاضَةِ إِلاَّ أَنْ تَغْتَسِلَ غُسْلاً وَاحِدًا ثُمَّ تَتَوَضَّأُ بَعْدَ ذَلِكَ لِكُلِّ صَلاَةٍ ‏.‏ قَالَ يَحْيَى قَالَ مَالِكٌ الأَمْرُ عِنْدَنَا أَنَّ الْمُسْتَحَاضَةَ إِذَا صَلَّتْ أَنَّ لِزَوْجِهَا أَنْ يُصِيبَهَا وَكَذَلِكَ النُّفَسَاءُ إِذَا بَلَغَتْ أَقْصَى مَا يُمْسِكُ النِّسَاءَ الدَّمُ فَإِنْ رَأَتِ الدَّمَ بَعْدَ ذَلِكَ فَإِنَّهُ يُصِيبُهَا زَوْجُهَا وَإِنَّمَا هِيَ بِمَنْزِلَةِ الْمُسْتَحَاضَةِ ‏.‏ قَالَ يَحْيَى قَالَ مَالِكٌ الأَمْرُ عِنْدَنَا فِي الْمُسْتَحَاضَةِ عَلَى حَدِيثِ هِشَامِ بْنِ عُرْوَةَ عَنْ أَبِيهِ وَهُوَ أَحَبُّ مَا سَمِعْتُ إِلَىَّ فِي ذَلِكَ ‏.‏\hadithno{138}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa that his father said, "A woman who bleeds as if menstruating only has to do one ghusl, and then after that she does wudu for each prayer." Yahya said that Malik said, "The position with us is that when a woman who bleeds as if menstruating starts to do the prayer again, her husband can have sexual intercourse with her. Similarly, if a woman who has given birth sees blood after she has reached the fullest extent that bleeding normally restrains women, her husband can have sexual intercourse with her and she is in the same position as a woman who bleeds as if menstruating." Yahya said that Malik said, "The position with us concerning a woman who bleeds as if menstruating is founded on the hadith of Hisham ibn Urwa from his father, and it is what I prefer the most of what I have heard about the matter}}
\hadithdefcmd{malik}{139}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ أُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِصَبِيٍّ فَبَالَ عَلَى ثَوْبِهِ فَدَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِمَاءٍ فَأَتْبَعَهُ إِيَّاهُ ‏.‏\hadithno{139}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, said, "An infant boy was brought to the Messenger of Allah, may Allah bless him and grant him peace, and it urinated on him. The Messenger of Allah, may Allah bless him and grant him peace, called for some water and rubbed over the urine with it}}
\hadithdefcmd{malik}{140}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، عَنْ أُمِّ قَيْسٍ بِنْتِ مِحْصَنٍ، أَنَّهَا أَتَتْ بِابْنٍ لَهَا صَغِيرٍ لَمْ يَأْكُلِ الطَّعَامَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَجْلَسَهُ فِي حَجْرِهِ فَبَالَ عَلَى ثَوْبِهِ فَدَعَا رَسُولُ اللَّهِ بِمَاءٍ فَنَضَحَهُ وَلَمْ يَغْسِلْهُ ‏.‏\hadithno{140}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Ubaydullah ibn Abdullah ibn Utba ibn Masud from Umm Qays ibn Mihsan that she brought a baby boy of hers who was not yet eating food to the Messenger of Allah, may Allah bless him and grant him peace, and he sat it in his arms and it urinated on his garment, so the Messenger of Allah, may Allah bless him and grant him peace, called for some water and sprinkled over it but did not wash it}}
\hadithdefcmd{malik}{141}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ قَالَ دَخَلَ أَعْرَابِيٌّ الْمَسْجِدَ فَكَشَفَ عَنْ فَرْجِهِ لِيَبُولَ فَصَاحَ النَّاسُ بِهِ حَتَّى عَلاَ الصَّوْتُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اتْرُكُوهُ ‏"‏ ‏.‏ فَتَرَكُوهُ فَبَالَ ثُمَّ أَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِذَنُوبٍ مِنْ مَاءٍ فَصُبَّ عَلَى ذَلِكَ الْمَكَانِ ‏.‏\hadithno{141}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Yahya related to me from Malik that Yahya ibn Said said, "A Bedouin came into the mosque and uncovered his private parts to urinate. The people called out to him and began to raise their voices but the Messenger of Allah, may Allah bless him and grant him peace, said ,'Let him be. 'So they let him be and he urinated. Then the Messenger of Allah, may Allah bless him and grant him peace, ordered a bucketful of water to be brought and it was poured on the place}}
\hadithdefcmd{malik}{142}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، أَنَّهُ قَالَ رَأَيْتُ عَبْدَ اللَّهِ بْنَ عُمَرَ يَبُولُ قَائِمًا ‏.‏ قَالَ يَحْيَى وَسُئِلَ مَالِكٌ عَنْ غَسْلِ الْفَرْجِ مِنَ الْبَوْلِ وَالْغَائِطِ هَلْ جَاءَ فِيهِ أَثَرٌ فَقَالَ بَلَغَنِي أَنَّ بَعْضَ مَنْ مَضَى كَانُوا يَتَوَضَّئُونَ مِنَ الْغَائِطِ وَأَنَا أُحِبُّ أَنْ أَغْسِلَ الْفَرْجَ مِنَ الْبَوْلِ ‏.‏\hadithno{142}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to mefrom Malikthat Abdullah ibn Dinar said, "I saw Abdullah ibn Umar urinating while standing." Yahya said that Malik was asked if any hadith had come down about washing the private parts of urine and faeces and he said, "I have heard that some of those who have passed away used to wash themselves of faeces. I like to wash my private parts of urine}}
\hadithdefcmd{malik}{143}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنِ ابْنِ السَّبَّاقِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ فِي جُمُعَةٍ مِنَ الْجُمَعِ ‏ "‏ يَا مَعْشَرَ الْمُسْلِمِينَ إِنَّ هَذَا يَوْمٌ جَعَلَهُ اللَّهُ عِيدًا فَاغْتَسِلُوا وَمَنْ كَانَ عِنْدَهُ طِيبٌ فَلاَ يَضُرُّهُ أَنْ يَمَسَّ مِنْهُ وَعَلَيْكُمْ بِالسِّوَاكِ ‏"‏ ‏.‏\hadithno{143}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Ibn as-Sabbaq that the Messenger of Allah, may Allah bless him and grant him peace, said in a jumua, "Muslims! Allah has made this day a festival day (id) so do ghusl, and it will not harm whoever has perfume to apply some of it, and use a tooth-stick}}
\hadithdefcmd{malik}{144}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَوْلاَ أَنْ أَشُقَّ عَلَى أُمَّتِي لأَمَرْتُهُمْ بِالسِّوَاكِ ‏"‏ ‏.‏\hadithno{144}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z Zinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "Were it not that I would be overburdening my community I would have ordered them to use a tooth-stick}}
\hadithdefcmd{malik}{145}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ قَالَ لَوْلاَ أَنْ يَشُقَّ، عَلَى أُمَّتِهِ لأَمَرَهُمْ بِالسِّوَاكِ مَعَ كُلِّ وُضُوءٍ ‏.‏\hadithno{145}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Humayd ibn Abdar-Rahman ibn Awf that Abu Hurayra said, "Were it not that he would be overburdening his community he (the Messenger of Allah, may Allah bless him and grant him peace,) would have ordered them to use a tooth-stick with each wudu}}
